@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2006 Bharat Mediratta
+ * Copyright (C) 2000-2007 Bharat Mediratta
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: albums.php 13362 2006-04-04 22:13:34Z jenst $
+ * $Id: albums.php 16803 2007-08-01 20:49:39Z jenst $
  */
 ?>
 <?php
@@ -86,33 +86,42 @@ $navigator["bordercolor"] = $borderColor;
 $displayCommentLegend = 0;  // this determines if we display "* Item contains a comment" at end of page
 
 if (!$GALLERY_EMBEDDED_INSIDE) {
-	doctype();
+    $title = htmlspecialchars($gallery->app->galleryTitle);
+
+    doctype();
 ?>
 <html>
 <head>
-  <title><?php echo $gallery->app->galleryTitle ?></title>
+  <title><?php echo $title ?></title>
   <?php
 	common_header() ;
 
 	/* prefetching/navigation */
-    if ($navigator['page'] > 1) { ?>
-  <link rel="top" href="<?php echo makeGalleryUrl('albums.php', array('set_albumListPage' => 1)) ?>">
-  <link rel="first" href="<?php echo makeGalleryUrl('albums.php', array('set_albumListPage' => 1)) ?>">
-  <link rel="prev" href="<?php echo makeGalleryUrl('albums.php', array('set_albumListPage' => $navigator['page']-1)) ?>">
+	$topUrl  = makeGalleryUrl('albums.php', array('set_albumListPage' => 1));
+    $firstUrl = makeGalleryUrl('albums.php',array('set_albumListPage' => 1));
+	$prevUrl = makeGalleryUrl('albums.php', array('set_albumListPage' => $navigator['page']-1));
+	$nextUrl = makeGalleryUrl('albums.php', array('set_albumListPage' => $navigator['page']+1));
+	$lastUrl = makeGalleryUrl('albums.php', array('set_albumListPage' => $maxPages));
+
+	if ($navigator['page'] > 1) {
+?>
+  <link rel="top" href="<?php echo $topUrl ?>">
+  <link rel="first" href="<?php echo $firstUrl ?>">
+  <link rel="prev" href="<?php echo  $prevUrl?>">
 <?php
     }
     if ($navigator['page'] < $maxPages) { ?>
-  <link rel="next" href="<?php echo makeGalleryUrl('albums.php', array('set_albumListPage' => $navigator['page']+1)) ?>">
-  <link rel="last" href="<?php echo makeGalleryUrl('albums.php', array('set_albumListPage' => $maxPages)) ?>">
+  <link rel="next" href="<?php echo $nextUrl ?>">
+  <link rel="last" href="<?php echo $lastUrl?>">
 <?php
     }
     if ($gallery->app->rssEnabled == "yes" && !$gallery->session->offline) {
-    	$title = sprintf(gTranslate('core', "%s RSS"), $gallery->app->galleryTitle);
-    	$rssHref = $gallery->app->photoAlbumURL . "/rss.php"
+    	$rssTitle = sprintf(gTranslate('core', "%s RSS"), $title);
+    	$rssHref = $gallery->app->photoAlbumURL . "/rss.php";
+
+        echo "<link rel=\"alternate\" title=\"$rssTitle\" href=\"$rssHref\" type=\"application/rss+xml\">";
+    }
 ?>
-  <link rel="alternate" title="<?php echo $title?>" href="<?php echo $rssHref ?>" type="application/rss+xml">
-<?php
-    } ?>
 </head>
 <body dir="<?php echo $gallery->direction ?>">
 <?php
@@ -121,7 +130,7 @@ if (!$GALLERY_EMBEDDED_INSIDE) {
 includeHtmlWrap("gallery.header");
 
 if (!$gallery->session->offline &&
-  ( ($gallery->app->showSearchEngine == 'yes' && $numPhotos != 0) || 
+  ( ($gallery->app->showSearchEngine == 'yes' && $numPhotos != 0) ||
   $GALLERY_EMBEDDED_INSIDE == 'phpBB2')) {
 ?>
 <table width="100%" border="0" cellspacing="0" style="margin-bottom:2px">
@@ -145,7 +154,7 @@ if (!$gallery->session->offline &&
 /* Admin Text (left side) */
 $adminText = '';
 if ($numAccess == $numAlbums) {
-	$toplevel_str = gTranslate('core', "1 album","%d albums", $numAlbums, gTranslate('core', "no albums"));
+	$toplevel_str = gTranslate('core', "1 album","%d albums", $numAlbums, gTranslate('core', "No albums"));
 } else {
 	$toplevel_str = gTranslate('core', "1 top-level album","%d top-level albums", $numAlbums, gTranslate('core', "No top-level albums"));
 }
@@ -181,48 +190,48 @@ if ($gallery->user->isLoggedIn() && !$gallery->session->offline) {
 }
 
 if ($gallery->app->gallery_slideshow_type != "off" && $numPhotos != 0) {
-    $iconText = getIconText('display.gif', gTranslate('core', "slideshow"));
+    $iconText = getIconText('display.gif', gTranslate('core', "Slideshow"));
     $iconElements[] = '<a href="'. makeGalleryUrl("slideshow.php",array("set_albumName" => null)) .'">'. $iconText .'</a>';
 }
 
 if ($gallery->user->canCreateAlbums() && !$gallery->session->offline) {
-    $iconText = getIconText('folder_new.gif', gTranslate('core', "new album"));
+    $iconText = getIconText('folder_new.gif', gTranslate('core', "New album"));
     $iconElements[] = '<a href="' . doCommand("new-album", array(), "view_album.php") .'">'. $iconText .'</a>';
 }
 
 if ($gallery->user->isLoggedIn() && !$gallery->session->offline) {
     if ($gallery->user->isAdmin()) {
-        
+
         $iconText = getIconText('unsortedList.gif', gTranslate('core', "Administer startpage"));
         $linkurl = makeGalleryUrl('administer_startpage.php', array('type' => 'popup'));
         $iconElements[] = popup_link($iconText, $linkurl, true);
-        
-        $iconText = getIconText('kdf.gif', gTranslate('core', "admin page"));
+
+        $iconText = getIconText('kdf.gif', gTranslate('core', "Admin page"));
         $iconElements[] = '<a href="'. makeGalleryUrl('admin-page.php') .'">'. $iconText .'</a> ';
-         
+
         $docsUrl = galleryDocs('admin');
         if ($docsUrl) {
-            $iconText = getIconText('info.gif', gTranslate('core', "documentation"));
+            $iconText = getIconText('info.gif', gTranslate('core', "Documentation"));
             $iconElements[] = "<a href=\"$docsUrl\">". $iconText .'</a>';
         }
     }
-    
+
     if ($gallery->userDB->canModifyUser()) {
-        $iconText = getIconText('yast_sysadmin.gif', gTranslate('core', "preferences"));
+        $iconText = getIconText('yast_sysadmin.gif', gTranslate('core', "Preferences"));
         $iconElements[] = popup_link($iconText, "user_preferences.php", false, true, 500, 500);
     }
-    
+
     if (!$GALLERY_EMBEDDED_INSIDE) {
-        $iconText = getIconText('exit.gif', gTranslate('core', "logout"));
+        $iconText = getIconText('exit.gif', gTranslate('core', "Logout"));
         $iconElements[] = '<a href="'. doCommand("logout", array(), "albums.php") .'">'. $iconText .'</a>';
     }
 } else {
     if (!$GALLERY_EMBEDDED_INSIDE) {
-        $iconText = getIconText('identity.gif', gTranslate('core', "login"));
+        $iconText = getIconText('identity.gif', gTranslate('core', "Login"));
         $iconElements[] = popup_link($iconText, "login.php", false, true, 500, 500);
 
         if (!strcmp($gallery->app->selfReg, 'yes')) {
-            $iconText = getIconText('yast_sysadmin2.gif', gTranslate('core', "register"));
+            $iconText = getIconText('yast_sysadmin2.gif', gTranslate('core', "Register"));
             $iconElements[] = popup_link($iconText, "register.php", false, true, 500, 500);
         }
     }
@@ -248,7 +257,7 @@ echo "<!-- End top nav -->";
 if ( (sizeof($albumDB->brokenAlbums) || sizeof($albumDB->outOfDateAlbums)) && $gallery->user->isAdmin()) {
 
 	echo "\n<center><div style=\"width:60%; border-style:outset; border-width:5px; border-color:red; padding: 5px;\">";
-	echo "\n<p class=\"head\"><u>". gTranslate('core', "Attention Gallery Administrator!") ."</u></p>";
+	echo "\n<p class=\"head\"><u>". gTranslate('core', "Attention Gallery administrator!") ."</u></p>";
 
 	if (sizeof($albumDB->brokenAlbums)) {
 		echo sprintf(gTranslate('core', "%s has detected the following %d invalid album(s) in your albums directory<br>(%s):"),
@@ -289,7 +298,7 @@ $start = ($gallery->session->albumListPage - 1) * $perPage + 1;
 $end = min($start + $perPage - 1, $numAlbums);
 for ($i = $start; $i <= $end; $i++) {
     if(!$gallery->album = $albumDB->getAlbum($gallery->user, $i)) {
-        echo gallery_error(sprintf(gTranslate('core', "The requested album with index %s is not valid"), $i));
+        echo gallery_error(sprintf(gTranslate('core', "The requested album with index %s is not valid."), $i));
         continue;
     }
     $isRoot = $gallery->album->isRoot(); // Only display album if it is a root album
@@ -330,7 +339,7 @@ for ($i = $start; $i <= $end; $i++) {
       }
       $gallery->html_wrap['imageWidth'] = $iWidth;
       $gallery->html_wrap['imageHeight'] = $iHeight;
-      $gallery->html_wrap['imageTag'] = $gallery->album->getHighlightTag($scaleTo,'', gTranslate('core', "Highlight for Album:") ." ". $gallery->album->fields["title"]);
+      $gallery->html_wrap['imageTag'] = $gallery->album->getHighlightTag($scaleTo,'', gTranslate('core', "Highlight for album:") ." ". $gallery->album->fields["title"]);
       $gallery->html_wrap['imageHref'] = $albumURL;
       $gallery->html_wrap['frame'] = $gallery->app->gallery_thumb_frame_style;
       includeHtmlWrap('inline_gallerythumb.frame');
@@ -351,7 +360,7 @@ for ($i = $start; $i <= $end; $i++) {
 			echo editField($gallery->album, "title", $albumURL);
 			if ($gallery->user->canDownloadAlbum($gallery->album) && $gallery->album->numPhotos(1)) {
 			    $iconText = getIconText('compressed.png', gTranslate('core', "Download entire album as archive"), 'yes');
-			    echo popup_link($iconText, "download.php?set_albumName=$tmpAlbumName",false,false,500,500); 
+			    echo popup_link($iconText, "download.php?set_albumName=$tmpAlbumName",false,false,500,500);
 			}
 		?>
               </td>
@@ -393,7 +402,7 @@ for ($i = $start; $i <= $end; $i++) {
 	* Url (only for admins and owner)
 	*/
 	if ($gallery->user->isAdmin() || $gallery->user->isOwnerOfAlbum($gallery->album)) {
-		echo gTranslate('core', "url:") . '<a href="'. $albumURL . '">';
+		echo gTranslate('core', "URL:") . ' <a href="'. $albumURL . '">';
 		if (!$gallery->session->offline) {
 			echo breakString(urldecode($albumURL), 60, '&', 5);
 		} else {
@@ -414,7 +423,7 @@ for ($i = $start; $i <= $end; $i++) {
 	}
 
 	echo "\n<br><span class=\"fineprint\">";
-	
+
 	/*
 	* Created / Last Changed
 	*/
@@ -426,7 +435,7 @@ for ($i = $start; $i <= $end; $i++) {
 	else {
 		printf(gTranslate('core', "Last changed on %s."), $lastModifiedDate);
 	}
-	
+
 	/*
 	* Amount of items
 	*/
@@ -434,13 +443,13 @@ for ($i = $start; $i <= $end; $i++) {
 	list($visibleItems) = $gallery->album->numItems($gallery->user, true);
 
 	echo gTranslate('core', "This album contains 1 item.", "This album contains %d items.", $visibleItems);
-	
+
 	/*
 	* Click counter + reset for it
 	*/
 	if (!($gallery->album->fields["display_clicks"] == "no") && !$gallery->session->offline) {
 		$clickCount = $gallery->album->getClicks();
-		
+
 		echo "\n<br>";
 		printf(gTranslate('core', "This album has been viewed %s since %s."),
 		  gTranslate('core', "1 time", "%d times", $clickCount, gTranslate('core', "0 times")),
@@ -451,7 +460,7 @@ for ($i = $start; $i <= $end; $i++) {
 	(!($gallery->album->fields["display_clicks"] == "no"))) {
 		echo " ".popup_link("[" . gTranslate('core', "reset counter") ."]", doCommand("reset-album-clicks", array("set_albumName" => $albumName), "albums.php"), 1);
 	}
-	
+
 	/*
 	* Comment Indicator
 	*/
@@ -468,7 +477,7 @@ for ($i = $start; $i <= $end; $i++) {
 	echo "\n</span>";
 
 	// End Album Infos
- 
+
  // Start tree
     if ( isset($gallery->app->albumTreeDepth) && $gallery->app->albumTreeDepth > 0)
 	if (isset($gallery->app->microTree) && $gallery->app->microTree == 'yes') { ?>
