@@ -1,9 +1,14 @@
 <?php
+/**
+ * Gallery SVN info
+ * $Id: htmlMimeMail.php 15794 2007-02-09 14:24:10Z jenst $
+*/
+
 /**
  * Filename.......: class.html.mime.mail.inc
  * Project........: HTML Mime mail class
- * Last Modified..: $Date: 2005/10/26 13:34:40 $
- * CVS Revision...: $Revision: 1.5 $
+ * Last Modified..: $Date: 2007-02-09 14:24:10 +0000 (Fri, 09 Feb 2007) $
+ * CVS Revision...: $Revision: 15794 $
  * Copyright......: 2001, 2002 Richard Heyes
  * @package Mail
 */
@@ -74,14 +79,14 @@ class htmlMimeMail
 	* @var boolean
 	*/
 	var $is_built;
-	
+
 	/**
     * The return path address. If not set the From:
 	* address is used instead
 	* @var string
     */
 	var $return_path;
-	
+
 	/**
     * Array of information needed for smtp sending
 	* @var array
@@ -132,10 +137,10 @@ class htmlMimeMail
 		/**
         * Defaults for smtp sending
         */
-		if (!empty($GLOBALS['HTTP_SERVER_VARS']['HTTP_HOST'])) {
-			$helo = $GLOBALS['HTTP_SERVER_VARS']['HTTP_HOST'];
-		} elseif (!empty($GLOBALS['HTTP_SERVER_VARS']['SERVER_NAME'])) {
-			$helo = $GLOBALS['HTTP_SERVER_VARS']['SERVER_NAME'];
+		if (!empty($_SERVER['HTTP_HOST'])) {
+			$helo = $_SERVER['HTTP_HOST'];
+		} elseif (!empty($_SERVER['SERVER_NAME'])) {
+			$helo = $_SERVER['SERVER_NAME'];
 		} else {
 			$helo = 'localhost';
 		}
@@ -354,7 +359,7 @@ class htmlMimeMail
 			// If duplicate images are embedded, they may show up as attachments, so remove them.
 			$html_images = array_unique($html_images);
 			sort($html_images);
-	
+
 			for ($i=0; $i<count($html_images); $i++) {
 				if ($image = $this->getFile($images_dir.$html_images[$i])) {
 					$ext = substr($html_images[$i], strrpos($html_images[$i], '.') + 1);
@@ -617,7 +622,7 @@ class htmlMimeMail
 
 			// Add message ID header
 			srand((double)microtime()*10000000);
-			$message_id = sprintf('<%s.%s@%s>', base_convert(time(), 10, 36), base_convert(rand(), 10, 36), !empty($GLOBALS['HTTP_SERVER_VARS']['HTTP_HOST']) ? $GLOBALS['HTTP_SERVER_VARS']['HTTP_HOST'] : $GLOBALS['HTTP_SERVER_VARS']['SERVER_NAME']);
+			$message_id = sprintf('<%s.%s@%s>', base_convert(time(), 10, 36), base_convert(rand(), 10, 36), !empty($_SERVER['HTTP_HOST']) ? $_SERVER['HTTP_HOST'] : $_SERVER['SERVER_NAME']);
 			$this->headers['Message-ID'] = $message_id;
 
 			$this->is_built = true;
@@ -638,7 +643,7 @@ class htmlMimeMail
 			$replacement = preg_replace('/([\x80-\xFF])/e', '"=" . strtoupper(dechex(ord("\1")))', $value);
 			$input = str_replace($value, '=?' . $charset . '?Q?' . $replacement . '?=', $input);
 		}
-		
+
 		return $input;
 	}
 
@@ -679,21 +684,22 @@ class htmlMimeMail
 				} else {
 					$result = mail($to, $subject, $this->output, implode(CRLF, $headers));
 				}
-				
+
 				// Reset the subject in case mail is resent
 				if ($subject !== '') {
 					$this->headers['Subject'] = $subject;
 				}
-				
+
 				// Return
 				return $result;
+
 				break;
 
 			case 'smtp':
 				require_once(dirname(__FILE__) . '/smtp.php');
 				require_once(dirname(__FILE__) . '/RFC822.php');
 				$smtp = &smtp::connect($this->smtp_params);
-				
+
 				// Parse recipients argument for internet addresses
 				foreach ($recipients as $recipient) {
 					$addresses = Mail_RFC822::parseAddressList($recipient, $this->smtp_params['helo'], null, false);
@@ -720,7 +726,7 @@ class htmlMimeMail
 				}
 				// Add To header based on $recipients argument
 				$headers[] = 'To: ' . $this->_encodeHeader(implode(', ', $recipients), $this->build_params['head_charset']);
-				
+
 				// Add headers to send_params
 				$send_params['headers']    = $headers;
 				$send_params['recipients'] = array_values(array_unique($smtp_recipients));
@@ -739,9 +745,12 @@ class htmlMimeMail
 				// Send it
 				if (!$smtp->send($send_params)) {
 					$this->errors = $smtp->errors;
+					echo gallery_error(_("Sending mail via the smtp method failed with these errors:"));
+					print_r($smtp->errors);
 					return false;
 				}
 				return true;
+
 				break;
 		}
 	}
