@@ -1,7 +1,7 @@
 <?php
 /*
 * Gallery - a web based photo album viewer and editor
-* Copyright (C) 2000-2006 Bharat Mediratta
+* Copyright (C) 2000-2007 Bharat Mediratta
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 *
-* $Id: download.php 13338 2006-03-27 15:32:14Z jenst $
+* $Id: download.php 16862 2007-08-12 14:13:11Z jenst $
 */
 ?>
 <?php
@@ -28,19 +28,19 @@ list($doit, $full) =
 getRequestVar(array('doit', 'full'));
 
 if (!empty($doit)) {
-    $albumItemNames = $gallery->album->getAlbumItemNames($gallery->user, $full, false, true);
-    $albumcopyName = createTempAlbum($albumItemNames);
-    if($albumcopyName) {
-    $zipfileName = createZip($albumcopyName, $gallery->album->fields['name']);
-        if($zipfileName) {
-            if(!isDebugging()) {
-    downloadFile($zipfileName);
-            }
-            else {
-                echo gallery_error('<br>'. _("Zipdownload would work, but is disabled when debugging."));
-            }
-        }
-    }
+	$albumItemNames = $gallery->album->getAlbumItemNames($gallery->user, $full, false, true);
+	$albumcopyName = createTempAlbum($albumItemNames);
+	if($albumcopyName) {
+		$zipfileName = createZip($albumcopyName, $gallery->album->fields['name']);
+		if($zipfileName) {
+			if(!isDebugging()) {
+				downloadFile($zipfileName);
+			}
+			else {
+				echo gallery_error('<br>'. gTranslate('core', "Zipdownload would work, but is disabled when debugging."));
+			}
+		}
+	}
 }
 else {
     list($numItems, $numAlbums, $numPhotos) = $gallery->album->numItems($gallery->user, true);
@@ -67,13 +67,13 @@ else {
     echo "</p>";
 
     $textNumItems = sprintf(gTranslate('core', "This album contains just one item in total.", "This album contains %d items in total.", $numItems), $numItems);
-    $textNumSubAlbums = sprintf(gTranslate('core', "One subalbum", "%d subalbums", $numAlbums, _("No subalbums")), $numAlbums);
-    $textNumPhotos = sprintf(gTranslate('core', "one photo/movie", "%d photos/movies", $numPhotos , _("no photo/movie")), $numPhotos);
+    $textNumSubAlbums = sprintf(gTranslate('core', "One subalbum", "%d subalbums", $numAlbums, gTranslate('core', "No subalbums")), $numAlbums);
+    $textNumPhotos = sprintf(gTranslate('core', "one photo/movie", "%d photos/movies", $numPhotos , gTranslate('core', "no photo/movie")), $numPhotos);
 
     echo sprintf("%s ". gTranslate('core', "%s and %s."), $textNumItems, $textNumSubAlbums, $textNumPhotos);
 
     if($numPhotos > 0) {
-        echo '<p>'. sprintf(gTranslate('core', "Approximitaly size of zipfile: %s"), formatted_filesize($albumSize)) .'</p>';
+        echo '<p>'. sprintf(gTranslate('core', "Approximate size of zipfile: %s"), formatted_filesize($albumSize)) .'</p>';
 
         echo makeFormIntro('download.php', array('onChange' => 'document.g1_form.submit()'), array('gallery_popup' => 'true'));
 
@@ -86,7 +86,7 @@ else {
     }
     else {
 	echo "<br><br>";
-	echo _("This album album is not empty, but contains no photo or movie! Download would'nt make sense.");
+	echo gTranslate('core', "This album is not empty, but contains no photo or movie! Download wouldn't make sense.");
 	echo "<br><br>";
         echo "\n". '<input type="button" value="'. gTranslate('core', "Close Window") .'" onclick="parent.close()">';
     }
