@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2006 Bharat Mediratta
+ * Copyright (C) 2000-2007 Bharat Mediratta
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: ecard_preview.php 13338 2006-03-27 15:32:14Z jenst $
+ * $Id: ecard_preview.php 15632 2007-01-02 06:01:08Z jenst $
  */
 ?>
 <?php
@@ -35,6 +35,12 @@ require_once(dirname(__FILE__) . '/init.php');
 
 $ecard = getRequestVar('ecard');
 
+if(!isset($gallery->album)) {
+    $pieces = explode('/', $ecard['image_name']);
+    $gallery->album = new Album;
+    $gallery->album->load($pieces[0]);
+}
+
 list($error,$ecard_data_to_parse) = get_ecard_template($ecard["template_name"]);
 
 if (!empty($error)) {
