@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2006 Bharat Mediratta
+ * Copyright (C) 2000-2007 Bharat Mediratta
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: init.php 13849 2006-06-19 12:22:19Z jenst $
+ * $Id: init.php 15632 2007-01-02 06:01:08Z jenst $
 */
 ?>
 <?php
@@ -26,7 +26,7 @@
 $sensitiveList = array('gallery', 'GALLERY_EMBEDDED_INSIDE', 'GALLERY_EMBEDDED_INSIDE_TYPE', 'GLOBALS');
 foreach ($sensitiveList as $sensitive) {
     if (!empty($_REQUEST[$sensitive])) {
-        print _("Security violation") ."\n";
+        echo "Security violation! Override attempt.\n";
         exit;
     }
 }
@@ -93,8 +93,7 @@ if (file_exists(dirname(__FILE__) . "/lib/devel.php")) {
 }
 
 /*
- * Now we can catch if were are in GeekLog
- * We also include the common lib file as we need it in initLanguage()
+ * Now we can catch if were are in GeekLog and if yes, include the common lib file.
  *
  * If the old example path is still set, remove it.
 */
@@ -104,9 +103,10 @@ if (!empty($gallery->app->geeklog_dir) && $gallery->app->geeklog_dir == "/path/t
 
 // Verify that the geeklog_dir isn't overwritten with a remote exploit
 if (!empty($gallery->app->geeklog_dir) && !realpath($gallery->app->geeklog_dir)) {
-    print _("Security violation") ."\n";
+    print _("Security violation. Geeklog Dir is invalid.") ."\n";
     exit;
-} elseif (!empty($gallery->app->geeklog_dir)) {
+}
+elseif (!empty($gallery->app->geeklog_dir)) {
     $GALLERY_EMBEDDED_INSIDE='GeekLog';
     $GALLERY_EMBEDDED_INSIDE_TYPE = 'GeekLog';
 
@@ -120,7 +120,8 @@ if (!empty($gallery->app->geeklog_dir) && !realpath($gallery->app->geeklog_dir))
 if (isset($gallery->app->devMode) && $gallery->app->devMode == 'yes') {
     ini_set("display_errors", "1");
     error_reporting(E_ALL);
-} else {
+}
+else {
     error_reporting(E_ALL & ~E_NOTICE);
 }
 
@@ -162,7 +163,14 @@ if(isset($gallery->app)) {
 */
 set_magic_quotes_runtime(0);
 
-/* Load classes and session information
+if (!isset($GALLERY_NO_SESSIONS)) {
+    require(dirname(__FILE__) . "/session.php");
+}
+
+// We need to init the language before we include the files below, as they contain gettext calls.
+initLanguage();
+
+/* Load classes
  * Note: Some classes and libs are loaded in util.php
 */
 require(dirname(__FILE__) . "/classes/Album.php");
@@ -176,15 +184,10 @@ require(dirname(__FILE__) . "/classes/LoggedInUser.php");
 require(dirname(__FILE__) . "/classes/UserDB.php");
 require(dirname(__FILE__) . "/classes/Comment.php");
 
-if (!isset($GALLERY_NO_SESSIONS)) {
-    require(dirname(__FILE__) . "/session.php");
-}
-
 $gallerySanity = gallerySanityCheck();
 
 /* Make sure that Gallery is set up properly */
 if ($gallerySanity != NULL) {
-    initLanguage();
     include_once(dirname(__FILE__) . "/includes/errors/$gallerySanity");
     exit;
 }
@@ -221,7 +224,9 @@ if (isset($GALLERY_EMBEDDED_INSIDE)) {
                 $gallery->session->username = $user_info["uname"];
                 $gallery->user = $gallery->userDB->getUserByUsername($gallery->session->username);
             }
+
             break;
+
         case 'phpnuke':
             /* we're in phpnuke */
             include_once(dirname(__FILE__) . "/classes/Database.php");
@@ -277,7 +282,9 @@ if (isset($GALLERY_EMBEDDED_INSIDE)) {
                 $gallery->session->username = $user_info[$gallery->database{'fields'}{'uname'}];
                 $gallery->user = $gallery->userDB->getUserByUsername($gallery->session->username);
             }
+
             break;
+
         case 'nsnnuke':
             /* we're in nsnnuke */
             include_once(dirname(__FILE__) . "/classes/Database.php");
@@ -324,9 +331,11 @@ if (isset($GALLERY_EMBEDDED_INSIDE)) {
                 $gallery->session->username = $user_info[$gallery->database{'fields'}{'uname'}];
                 $gallery->user = $gallery->userDB->getUserByUsername($gallery->session->username);
             }
+
             break;
+
         case 'phpBB2':
-        //print_r($GLOBALS['board_config']['version']);
+            //print_r($GLOBALS['board_config']['version']);
             include_once(dirname(__FILE__) . "/classes/Database.php");
             include_once(dirname(__FILE__) . "/classes/database/mysql/Database.php");
             include_once(dirname(__FILE__) . "/classes/phpbb/UserDB.php");
@@ -358,7 +367,9 @@ if (isset($GALLERY_EMBEDDED_INSIDE)) {
             elseif ($gallery->session->username) {
                 $gallery->user = $gallery->userDB->getUserByUsername($gallery->session->username);
             }
+
             break;
+
         case 'mambo':
         case 'joomla':
             include_once(dirname(__FILE__) . '/classes/Database.php');
@@ -385,7 +396,8 @@ if (isset($GALLERY_EMBEDDED_INSIDE)) {
                 $mosConfig_dbprefix	= $gallery->session->mambo->mosConfig_dbprefix;
                 $mosConfig_lang		= $gallery->session->mambo->mosConfig_lang;
                 $MOS_GALLERY_PARAMS	= $gallery->session->mambo->MOS_GALLERY_PARAMS;
-            } elseif (!empty($mosConfig_db)) {
+            }
+            elseif (!empty($mosConfig_db)) {
                 $gallery->session->mambo->mosRoot = dirname($_SERVER['PHP_SELF']);
                 if (substr($gallery->session->mambo->mosRoot, -1) != '/') {
                     $gallery->session->mambo->mosRoot .= '/';
@@ -397,15 +409,15 @@ if (isset($GALLERY_EMBEDDED_INSIDE)) {
                 $gallery->session->mambo->mosConfig_dbprefix = $mosConfig_dbprefix;
                 $gallery->session->mambo->mosConfig_lang     = $mosConfig_lang;
                 $gallery->session->mambo->MOS_GALLERY_PARAMS = $MOS_GALLERY_PARAMS;
-            } else {
+            }
+            else {
                 echo 'init.php: ' . _("Gallery seems to be inside Mambo, but we couldn't get the necessary info.");
                 exit;
             }
 
             $gallery->database{'mambo'} = new MySQL_Database($mosConfig_host, $mosConfig_user, $mosConfig_password, $mosConfig_db);
             $gallery->database{'user_prefix'} = $mosConfig_dbprefix;
-            $gallery->database{'fields'} =
-            array (
+            $gallery->database{'fields'} = array (
                 'name'  => 'name',
                 'uname' => 'username',
                 'email' => 'email',
@@ -440,7 +452,9 @@ if (isset($GALLERY_EMBEDDED_INSIDE)) {
             $results = $db->query('SELECT id FROM ' . $gallery->database{'user_prefix'} . "menu WHERE componentid='$componentId' AND type = 'components' AND published = 1");
             $row = $db->fetch_row($results);
             $MOS_GALLERY_PARAMS['itemid'] = $row[0]; // pick the first one
+
             break;
+
         case 'GeekLog':
             // Cheat, and grab USER information from the global session variables.
             // Hey, it's faster and easier than reading them out of the database.
@@ -467,7 +481,9 @@ if (isset($GALLERY_EMBEDDED_INSIDE)) {
             if (isset($gallery->session->username)) {
                 $gallery->user = $gallery->userDB->getUserByUsername($gallery->session->username);
             }
+
             break;
+
         case 'cpgnuke':
             /* we're in CPG-Nuke */
             include_once(dirname(__FILE__) . "/classes/Database.php");
@@ -537,10 +553,18 @@ if (!isset($gallery->user) || empty($gallery->user)) {
     $gallery->session->username = "";
 }
 
-/* Now we init the language
- * Its done after initializing the user.
+/*
+ * 18.12.2006
+ * In previous Versions we did a second language init after the user init.
+ * But i do'nt see a reason a reason. So i commented it out.
+ if (!empty($gallery->user)) {
+     $userlanguage = $gallery->user->getDefaultLanguage();
+ 
+     if($userlanguage != $gallery->language) {
+         initLanguage(true, $userlanguage);
+     }
+ }
 */
-initLanguage();
 
 if (!isset($gallery->session->offline)) {
     $gallery->session->offline = FALSE;
