@@ -1,7 +1,7 @@
 <?php
 /**
  * Gallery SVN info
- * $Id: multifile.js.php 14113 2006-07-29 03:27:13Z jenst $
+ * $Id: multifile.js.php 16803 2007-08-01 20:49:39Z jenst $
 */
 ?>
 <script language="JavaScript" type="text/javascript">
@@ -100,6 +100,7 @@ function MultiSelector(list_target, max, fieldname, withCaption){
         line.style.textAlign='right';
         if(! (this.count % 2)) {
         	line.style.backgroundColor='white';
+		line.style.color='black';
         }
         var filenameCaptionDiv = document.createElement('div');
         filenameCaptionDiv.style.textAlign='left';
@@ -109,7 +110,7 @@ function MultiSelector(list_target, max, fieldname, withCaption){
         // Delete button
         var deleteButton = document.createElement('input');
         deleteButton.type = 'button';
-        deleteButton.value = '<?php echo _("Delete"); ?>';
+        deleteButton.value = '<?php echo gTranslate('core', "Delete"); ?>';
 
         // Caption field
         var caption = document.createElement('input');
@@ -146,7 +147,7 @@ function MultiSelector(list_target, max, fieldname, withCaption){
 
         if(withCaption) {
             // Set row value
-            filenameCaptionDiv.innerHTML = '<b>'+ element.value +'</b><br><?php echo _("Caption:"); ?> ';
+            filenameCaptionDiv.innerHTML = '<b>'+ element.value +'</b><br><?php echo gTranslate('core', "Caption:"); ?> ';
             // Add caption
             filenameCaptionDiv.appendChild(caption);
         }
