@@ -11,7 +11,7 @@
  *
  * Jens Tkotz 25.04.2005
  *
- * $Id: colorpicker.php 13580 2006-05-02 10:22:26Z jenst $
+ * $Id: colorpicker.php 16697 2007-06-28 10:31:31Z jenst $
 */
 
 /*
@@ -39,7 +39,7 @@ doctype();
 ?>
 <html>
 <head>
-  <title><?php echo _("Color Picker") ?></title>
+  <title><?php echo gTranslate('common', "Color Picker") ?></title>
   <?php echo getStyleSheetLink();; ?>
 </head>
 
@@ -51,13 +51,13 @@ doctype();
 function changeColor(color)
 {
     if (parent.opener.closed) {
-        alert("<?php echo addslashes(_("The Options window has closed. Exiting.")) ?>");
+        alert("<?php echo addslashes(gTranslate('common', "The Options window has closed. Exiting.")) ?>");
         this.close();
         return;
     }
 
     if (!parent.opener.document.getElementById('<?php echo $target ?>')) {
-        alert("<?php echo addslashes(_("This window must be called from an Options window")) ?>");
+        alert("<?php echo addslashes(gTranslate('common', "This window must be called from an Options window.")) ?>");
         this.close();
         return;
     }
