@@ -1,23 +1,23 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2006 Bharat Mediratta
- * 
+ * Copyright (C) 2000-2007 Bharat Mediratta
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: imageManipulation.php 13579 2006-05-02 09:59:13Z jenst $
+ * $Id: imageManipulation.php 16803 2007-08-01 20:49:39Z jenst $
  */
 
 /**
@@ -33,7 +33,7 @@
  *  2:  Existing resized file should be removed
  */
 function resize_image($src, $dest, $target = 0, $target_fs = 0, $keepProfiles = 0, $createThumbnail = false, $quality = 0) {
-    debugMessage(sprintf(_("Resizing Image: %s"), $src), __FILE__, __LINE__);
+    debugMessage(sprintf(gTranslate('common', "Resizing Image: %s."), $src), __FILE__, __LINE__);
 
     global $gallery;
 
@@ -62,9 +62,9 @@ function resize_image($src, $dest, $target = 0, $target_fs = 0, $keepProfiles =
     }
 
     /* Check for images smaller then target size, don't blow them up. */
-    if ((empty($target) || ($width <= $target && $height <= $target)) && 
+    if ((empty($target) || ($width <= $target && $height <= $target)) &&
       (empty($target_fs) || ((int) fs_filesize($src) >> 10) <= $target_fs)) {
-        echo debugMessage("&nbsp;&nbsp;&nbsp;". _("No resizing required"), __FILE__, __LINE__,1);
+        echo debugMessage("&nbsp;&nbsp;&nbsp;". gTranslate('common', "No resizing required."), __FILE__, __LINE__,1);
 
         /* If the file is already smaller than the target filesize, don't
         * create a new sized image.  return 2 indicates that the current .sized.
@@ -91,17 +91,17 @@ function resize_image($src, $dest, $target = 0, $target_fs = 0, $keepProfiles =
         if (!isset($quality)) {
             $quality = $gallery->album->fields['last_quality'];
         }
-        processingMsg("&nbsp;&nbsp;&nbsp;". sprintf(_("target file size %d kbytes"), $target_fs)."\n");
+        processingMsg("&nbsp;&nbsp;&nbsp;". sprintf(gTranslate('common', "Target file size: %d kbytes."), $target_fs)."\n");
 
         $loop = 0;
         do {
             $loop ++;
-            processingMsg("Loop: $loop"); 
+            processingMsg("Loop: $loop");
             compressImage($src, $out, $target, $quality, $keepProfiles, $createThumbnail);
 
             $prev_quality = $quality;
-            printf(_("-> file size %d kbytes"), round($filesize));
-            processingMsg("&nbsp;&nbsp;&nbsp;" . sprintf(_("trying quality %d%%"), $quality));
+            printf(gTranslate('common', "-> File size: %d kbytes"), round($filesize));
+            processingMsg("&nbsp;&nbsp;&nbsp;" . sprintf(gTranslate('common', "Trying quality: %d%%."), $quality));
             clearstatcache();
             $filesize = (int)fs_filesize($out) >> 10;
             if ($filesize < $target_fs) {
@@ -119,24 +119,27 @@ function resize_image($src, $dest, $target = 0, $target_fs = 0, $keepProfiles =
             if ($quality == $prev_quality) {
                 if ($filesize == $max_filesize) {
                     $quality--;
-                } else {
+                }
+                else {
                     $quality++;
                 }
             }
-        } while ($max_quality-$min_quality > 2 &&
-        abs(($filesize-$target_fs)/$target_fs) > .02 );
+        }
+        while ($max_quality-$min_quality > 2 && abs(($filesize-$target_fs)/$target_fs) > .02 );
 
         $gallery->album->fields['last_quality'] = $prev_quality;
-        printf(_("-> file size %d kbytes"), round($filesize));
-        processingMsg(_("Done."));
+        printf(gTranslate('common', "-> File size: %d kbytes"), round($filesize));
+        processingMsg(gTranslate('common', "Done."));
     }
+    
     if (fs_file_exists("$out") && fs_filesize("$out") > 0) {
         if ($useTemp) {
             fs_copy($out, $dest);
             fs_unlink($out);
         }
         return 1;
-    } else {
+    }
+    else {
         return 0;
     }
 }
@@ -149,40 +152,46 @@ function resize_image($src, $dest, $target = 0, $target_fs = 0, $keepProfiles =
  * Returns a list of 2 temporary files (overlay, and alphamask), these files should be deleted (unlinked)
  * by the calling function
  */
-function netpbm_decompose_image($input, $format) {
+function Netpbm_decompose_image($input, $format) {
     global $gallery;
-    $overlay = tempnam($gallery->app->tmpDir, "netpbm_");
-    $alpha = tempnam($gallery->app->tmpDir, "netpbm_");
     
+    $overlay = tempnam($gallery->app->tmpDir, "Netpbm_");
+    $alpha = tempnam($gallery->app->tmpDir, "Netpbm_");
+
     switch ($format) {
         case "png":
-            $getOverlay = netPBM("pngtopnm", "$input > $overlay");
-            $getAlpha   = netPBM("pngtopnm", "-alpha $input > $alpha");
+            $getOverlay = Netpbm("pngtopnm", "$input > $overlay");
+            $getAlpha   = Netpbm("pngtopnm", "-alpha $input > $alpha");
         break;
         case "gif":
-            $getOverlay = netPBM("giftopnm", "--alphaout=$alpha $input > $overlay");
+            $getOverlay = Netpbm("giftopnm", "--alphaout=$alpha $input > $overlay");
         break;
             case "tif":
-        $getOverlay = netPBM("tifftopnm", "-alphaout=$alpha $input > $overlay");
+        $getOverlay = Netpbm("tifftopnm", "-alphaout=$alpha $input > $overlay");
         break;
     }
-    
+
     exec_wrapper($getOverlay);
+    
     if (isset($getAlpha)) {
         exec_wrapper($getAlpha);
     }
+    
     return array($overlay, $alpha);
 }
 
 function watermark_image($src, $dest, $wmName, $wmAlphaName, $wmAlign, $wmAlignX, $wmAlignY) {
     global $gallery;
+    
     if (!strcmp($src,$dest)) {
         $useTemp = true;
         $out = "$dest.tmp";
-    } else {
+    }
+    else {
         $useTemp = false;
         $out = $dest;
     }
+    
     if (isDebugging()) {
         print "<table border=\"1\">";
         print "<tr><td>src</td><td>$src</td></tr>";
@@ -202,17 +211,20 @@ function watermark_image($src, $dest, $wmName, $wmAlphaName, $wmAlign, $wmAlignX
                 $overlayFile = $wmName;
             break;
 
-            case 'NetPBM':
+            case 'Netpbm':
                 if (eregi('\.png$',$wmName, $regs)) {
-                    list ($overlayFile, $alphaFile) = netpbm_decompose_image($wmName, "png");
+                    list ($overlayFile, $alphaFile) = Netpbm_decompose_image($wmName, "png");
                     $tmpOverlay = 1;
-                } elseif (eregi('\.tiff?$',$wmName, $regs)) {
-                    list ($overlayFile, $alphaFile) = netpbm_decompose_image($wmName, "tif");
+                }
+                elseif (eregi('\.tiff?$',$wmName, $regs)) {
+                    list ($overlayFile, $alphaFile) = Netpbm_decompose_image($wmName, "tif");
                     $tmpOverlay = 1;
-                } elseif (eregi('\.gif$',$wmName, $regs)) {
-                    list ($overlayFile, $alphaFile) = netpbm_decompose_image($wmName, "gif");
+                }
+                elseif (eregi('\.gif$',$wmName, $regs)) {
+                    list ($overlayFile, $alphaFile) = Netpbm_decompose_image($wmName, "gif");
                     $tmpOverlay = 1;
-                } else {
+                }
+                else {
                     $alphaFile = $wmName;
                     if (strlen($wmAlphaName)) {
                         $overlayFile = $wmAlphaName;
@@ -220,11 +232,12 @@ function watermark_image($src, $dest, $wmName, $wmAlphaName, $wmAlign, $wmAlignX
                 }
             break;
             default:
-                echo debugMessage(_("You have no graphics package configured for use!"), __FILE__, __LINE__);
+                echo debugMessage(gTranslate('common', "You have no graphics package configured for use!"), __FILE__, __LINE__);
             return 0;
         }
-    } else {
-        echo gallery_error(_("No watermark name specified!"));
+    }
+    else {
+        echo gallery_error(gTranslate('common', "No watermark name specified!"));
         return 0;
     }
 
@@ -277,7 +290,7 @@ function watermark_image($src, $dest, $wmName, $wmAlphaName, $wmAlign, $wmAlignX
             } else {
                 $wmAlignX = 0;
             }
-    
+
             if (ereg('([0-9]+)(\%?)', $wmAlignY, $regs)) {
                 if ($regs[2] == '%') {
                     $wmAlignY = round($regs[1] / 100 * ($srcSize[1] - $overlaySize[1]));
@@ -287,7 +300,7 @@ function watermark_image($src, $dest, $wmName, $wmAlphaName, $wmAlign, $wmAlignX
             } else {
                 $wmAlignY = 0;
             }
-    
+
             // clip left side
             if ($wmAlignX < 1) {
                 $wmAlignX = 0;
@@ -310,20 +323,28 @@ function watermark_image($src, $dest, $wmName, $wmAlphaName, $wmAlign, $wmAlignX
     $wmAlignX = floor($wmAlignX);
     $wmAlignY = floor($wmAlignY);
 
+    if ($wmAlignX > 0) {
+        $wmAlignX = '+'. $wmAlignX;
+    }
+
+    if ($wmAlignY > 0) {
+        $wmAlignY = '+'. $wmAlignY;
+    }
+
     // Execute
     switch($gallery->app->graphics) {
         case 'ImageMagick':
-            $srcOperator = "-geometry +$wmAlignX+$wmAlignY $overlayFile";
+            $srcOperator = "-geometry $wmAlignX$wmAlignY $overlayFile";
             exec_wrapper(ImCmd('composite', $srcOperator, $src, '', $out));
         break;
 
-        case 'NetPBM':
+        case 'Netpbm':
             $args  = "-yoff=$wmAlignY -xoff=$wmAlignX ";
             if ($alphaFile) {
                 $args .= "-alpha=$alphaFile ";
             }
             $args .= $overlayFile;
-            exec_wrapper(toPnmCmd($src) ." | ". NetPBM($gallery->app->pnmcomp, $args) ." | " . fromPnmCmd($out));
+            exec_wrapper(toPnmCmd($src) ." | ". Netpbm($gallery->app->pnmcomp, $args) ." | " . fromPnmCmd($out));
         break;
     }
 
@@ -390,10 +411,10 @@ function rotate_image($src, $dest, $target, $type) {
         exec_internal(fs_import_filename($path, 1) . " $args -trim -copy all -outfile $outFile $srcFile");
     } else {
         switch($gallery->app->graphics) {
-            case "NetPBM":
+            case "Netpbm":
                 $args2 = '';
                 if (!strcmp($target, '-90')) {
-                    /* NetPBM's docs mix up CW and CCW...
+                    /* Netpbm's docs mix up CW and CCW...
                     * We'll do it right. */
                     $args = '-r270';
                 } elseif (!strcmp($target, '180')) {
@@ -407,9 +428,9 @@ function rotate_image($src, $dest, $target, $type) {
                 } elseif (!strcmp($target, 'tr')) {
                     $args = '-xy';
                 } elseif (!strcmp($target, 'tv')) {
-                    /* Because of NetPBM inconsistencies, the only
+                    /* Because of Netpbm inconsistencies, the only
                     * way to do this transformation on *all*
-                    * versions of NetPBM is to pipe two separate
+                    * versions of Netpbm is to pipe two separate
                     * operations in sequence. Versions >= 10.13
                     * have the new -xform flag, and versions <=
                     * 10.6 could take the '-xy -r180' commands in
@@ -417,16 +438,16 @@ function rotate_image($src, $dest, $target, $type) {
                     * do *either*, so we're left with this little
                     * workaround. -Beckett 9/9/2003 */
                     $args = '-xy';
-                    $args2 = ' | ' . NetPBM('pnmflip', '-r180');
+                    $args2 = ' | ' . Netpbm('pnmflip', '-r180');
                 } else {
                     $args = '';
                 }
-    
+
                 exec_wrapper(toPnmCmd($src) . ' | ' .
-                NetPBM('pnmflip', $args) .
+                Netpbm('pnmflip', $args) .
                 $args2 .
                 ' | ' . fromPnmCmd($out));
-    
+
                 // copy exif headers from original image to rotated image
                 if (isset($gallery->app->use_exif)) {
                     $path = $gallery->app->use_exif;
@@ -451,12 +472,12 @@ function rotate_image($src, $dest, $target, $type) {
                 } else {
                     $destOperator = '';
                 }
-    
+
                 exec_wrapper(ImCmd('convert', '', $srcFile, $destOperator, $outFile));
             break;
             default:
                 if (isDebugging())
-                echo "<br>". _("You have no graphics package configured for use!") ."<br>";
+                echo "<br>". gTranslate('common', "You have no graphics package configured for use!") ."<br>";
                 return 0;
             break;
         }
@@ -474,7 +495,7 @@ function rotate_image($src, $dest, $target, $type) {
 }
 
 function cut_image($src, $dest, $offsetX, $offsetY, $width, $height) {
-    echo debugMessage(_("Cropping Image"),__FILE__, __LINE__);
+    echo debugMessage(gTranslate('common', "Cropping Image"),__FILE__, __LINE__);
     global $gallery;
 
     if (!strcmp($src,$dest)) {
@@ -489,10 +510,10 @@ function cut_image($src, $dest, $offsetX, $offsetY, $width, $height) {
     $outFile = fs_import_filename($out);
 
     switch($gallery->app->graphics) {
-        case "NetPBM":
+        case "Netpbm":
             exec_wrapper(toPnmCmd($src) .
             " | " .
-            NetPBM("pnmcut") .
+            Netpbm("pnmcut") .
             " $offsetX $offsetY $width $height" .
             " | " .
             fromPnmCmd($out));
@@ -508,7 +529,7 @@ function cut_image($src, $dest, $offsetX, $offsetY, $width, $height) {
         break;
         default:
             if (isDebugging()) {
-                echo "<br>" . _("You have no graphics package configured for use!") ."<br>";
+                echo "<br>" . gTranslate('common', "You have no graphics package configured for use!") ."<br>";
                 return 0;
             }
         break;
@@ -538,7 +559,7 @@ function cropImageToRatio($src, $dest, $destSize, $ratio) {
 
     switch($ratio) {
         case '1/1':
-        debugMessage(sprintf(_("Generating squared Version to %dpx"), $destSize), __FILE__, __LINE__);
+        debugMessage(sprintf(gTranslate('common', "Generating squared version to %d pixels."), $destSize), __FILE__, __LINE__);
 
         if($width > $height && $height > $destSize) {
             $offsetX = round(($width - $height)/2);
@@ -559,7 +580,7 @@ function cropImageToRatio($src, $dest, $destSize, $ratio) {
             $size);
         }
         else {
-            debugMessage(_("No Cropping Done"), __FILE__, __LINE__);
+            debugMessage(gTranslate('common', "No Cropping Done."), __FILE__, __LINE__);
             $ret = false;
         }
         break;
@@ -569,11 +590,11 @@ function cropImageToRatio($src, $dest, $destSize, $ratio) {
 
 function valid_image($file) {
     if (($type = getimagesize($file)) == FALSE) {
-        debugMessage(sprintf(_("Call to %s failed in %s for file %s!"), 'getimagesize()', 'valid_image()', $file), __FILE__, __LINE__);
+        debugMessage(sprintf(gTranslate('common', "Call to %s failed in %s for file %s!"), 'getimagesize()', 'valid_image()', $file), __FILE__, __LINE__);
         return 0;
     }
 
-    debugMessage(sprintf(_("File %s type %d."), $file, $type[2]), __FILE__, __LINE__);
+    debugMessage(sprintf(gTranslate('common', "File %s type %d."), $file, $type[2]), __FILE__, __LINE__);
 
     switch($type[2]) {
         case 1: // GIF
@@ -599,18 +620,18 @@ function toPnmCmd($file) {
 	case 'jpg':
 	case 'jpeg':
 	    $cmd = "jpegtopnm";
-	break;	
+	break;
 	case 'gif':
 	    $cmd = "giftopnm";
 	break;
     }
 
     if (!empty($cmd)) {
-	return netPBM($cmd) .' '. fs_import_filename($file);
+	return Netpbm($cmd) .' '. fs_import_filename($file);
     }
     else {
 	echo gallery_error(
-	  sprintf(_("Files with type %s are not supported by Gallery with netPBM"), $type)
+	  sprintf(gTranslate('common', "Files with type %s are not supported by Gallery with Netpbm."), $type)
 	);
 	return '';
     }
@@ -623,25 +644,25 @@ function fromPnmCmd($file, $quality = NULL) {
     }
 
     if (eregi("\.png(\.tmp)?\$", $file)) {
-	$cmd = netPBM("pnmtopng");
+	$cmd = Netpbm("pnmtopng");
     } elseif (eregi("\.jpe?g(\.tmp)?\$", $file)) {
-	$cmd = netPBM($gallery->app->pnmtojpeg, "--quality=$quality");
+	$cmd = Netpbm($gallery->app->pnmtojpeg, "--quality=$quality");
     } elseif (eregi("\.gif(\.tmp)?\$", $file)) {
-	$cmd = netPBM("ppmquant", "256") . " | " . NetPBM("ppmtogif");
+	$cmd = Netpbm("ppmquant", "256") . " | " . Netpbm("ppmtogif");
     }
 
     if (!empty($cmd)) {
 	return "$cmd > " . fs_import_filename($file);
     } else {
 	echo gallery_error(
-	  sprintf(_("Files with type %s are not supported by Gallery with netPBM"), 
+	  sprintf(gTranslate('common', "Files with type %s are not supported by Gallery with Netpbm."),
 	  getExtension($file))
 	);
 	return '';
     }
 }
 
-function netPBM($cmd, $args = '') {
+function Netpbm($cmd, $args = '') {
 	global $gallery;
 
 	$cmd = fs_import_filename($gallery->app->pnmDir . "/$cmd");
@@ -666,35 +687,35 @@ function netPBM($cmd, $args = '') {
 function ImCmd($cmd, $srcOperator, $src, $destOperator, $dest) {
     global $gallery;
     static $ImVersion;
-    
+
     if(empty($ImVersion)) {
         $ImVersion = floor(getImVersion());
     }
     $cmd = fs_import_filename($gallery->app->ImPath . "/$cmd");
-    
+
     if($ImVersion < 6) {
         $cmdLine = "$cmd $srcOperator $destOperator $src $dest";
     }
     else {
         $cmdLine = "$cmd $srcOperator $src $destOperator $dest";
     }
-    
+
     return $cmdLine;
 }
 
 function compressImage($src = '', $dest = '', $targetSize = 0, $quality, $keepProfiles = false, $createThumbnail = false) {
-    debugMessage(sprintf(_("Compressing image: %s"), $src), __FILE__, __LINE__); 
+    debugMessage(sprintf(gTranslate('common', "Compressing image: %s"), $src), __FILE__, __LINE__);
     global $gallery;
     static $ImVersion;
 
     if (empty($src) || empty($dest)) {
-        echo gallery_error(_("Not all necessary params for resizing given."));
-        echo debugMessage(sprintf(_("Resizing params: src: %s, dest : %s, targetSize: %s"), $src, $dest, $targetSize), __FILE__, __LINE__);
+        echo gallery_error(gTranslate('common', "Not all necessary params for resizing given."));
+        echo debugMessage(sprintf(gTranslate('common', "Resizing params: src: %s, dest : %s, targetSize: %s"), $src, $dest, $targetSize), __FILE__, __LINE__);
         return false;
     }
 
     $stripProfiles = '';
-    
+
     if(empty($ImVersion)) {
         $ImVersion = floor(getImVersion());
     }
@@ -707,10 +728,10 @@ function compressImage($src = '', $dest = '', $targetSize = 0, $quality, $keepPr
     $destFile = fs_import_filename($dest);
 
     switch($gallery->app->graphics)	{
-        case "NetPBM":
+        case "Netpbm":
             if ($targetSize) {
                  $result = exec_wrapper(toPnmCmd($src) .' | '.
-                        NetPBM('pnmscale', " -xysize $targetSize $targetSize")  .' | '.
+                        Netpbm('pnmscale', " -xysize $targetSize $targetSize")  .' | '.
                         fromPnmCmd($dest, $quality)
                 );
             }
@@ -722,7 +743,7 @@ function compressImage($src = '', $dest = '', $targetSize = 0, $quality, $keepPr
             if (!$result) {
                 return false;
             }
-            
+
             /* copy over EXIF data if a JPEG if $keepProfiles is set.
             *  Unfortunately, we can't also keep comments.
             */
@@ -732,7 +753,7 @@ function compressImage($src = '', $dest = '', $targetSize = 0, $quality, $keepPr
                     . $srcFile . ' ' . $destFile);
                     return true;
                 } else {
-                    processingMsg(_('Unable to preserve EXIF data (jhead not installed)') . "\n");
+                    processingMsg(gTranslate('common', "Unable to preserve EXIF data (jhead not installed).") . "\n");
                     return true;
                 }
             }
@@ -742,7 +763,7 @@ function compressImage($src = '', $dest = '', $targetSize = 0, $quality, $keepPr
             * 6.0.0 changed the parameters.
             * Preserve comment, EXIF data if a JPEG if $keepProfiles is set.
             */
-            if(!$keepProfiles || $createThumbnail) {   
+            if(!$keepProfiles || $createThumbnail) {
                 switch ($ImVersion) {
                     case '5':
                         $stripProfiles = ' +profile \'*\' ';
@@ -775,11 +796,11 @@ function compressImage($src = '', $dest = '', $targetSize = 0, $quality, $keepPr
                     }
                     else {
                         if($gallery->app->IM_HQ == 'yes') {
-                            echo debugMessage(_("Using IM high quality"), __FILE__, __LINE__, 3);
+                            echo debugMessage(gTranslate('common', "Using IM high quality."), __FILE__, __LINE__, 3);
                         }
                         else {
                             $srcOperator = "-size ${targetSize}x${targetSize}";
-                            echo debugMessage(_("Not using IM high quality"), __FILE__, __LINE__, 3);
+                            echo debugMessage(gTranslate('common', "Not using IM high quality."), __FILE__, __LINE__, 3);
                         }
                         $destOperator .= " -resize ${targetSize}x${targetSize} $stripProfiles";
                     }
@@ -787,10 +808,10 @@ function compressImage($src = '', $dest = '', $targetSize = 0, $quality, $keepPr
                 //$geometryCmd = "-coalesce -geometry ${targetSize}x${targetSize} ";
             }
 
-            return exec_wrapper(ImCmd('convert', $srcOperator, $srcFile, $destOperator, $destFile)); 
+            return exec_wrapper(ImCmd('convert', $srcOperator, $srcFile, $destOperator, $destFile));
         break;
         default:
-            echo debugMessage(_("You have no graphics package configured for use!"), __FILE__, __LINE__);
+            echo debugMessage(gTranslate('common', "You have no graphics package configured for use!"), __FILE__, __LINE__);
             return false;
         break;
     }
