@@ -1,24 +1,24 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2006 Bharat Mediratta
- * 
+ * Copyright (C) 2000-2007 Bharat Mediratta
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: lang.php 13579 2006-05-02 09:59:13Z jenst $
- */
+ * $Id: lang.php 16803 2007-08-01 20:49:39Z jenst $
+*/
 
 /**
  * @package	Language
@@ -30,13 +30,13 @@
  * 1.) We can use %s and %d in translation
  * 2.) We can use a special "none" without modifying the plural definition.
  *
- * @param	string    $domain
- * @param	string    $singular
- * @param	string    $plural
- * @param	int       $count
- * @param	string    $nonetext
- * @return      string    $translation	string with translation on success, otherwise '--- TranslationError --'
- * @author	Jens Tkotz
+ * @param   string  $domain
+ * @param   string  $singular
+ * @param   string  $plural
+ * @param   int     $count
+ * @param   string  $nonetext
+ * @return  string  $translation	string with translation on success, otherwise '--- TranslationError --'
+ * @author  Jens Tkotz
  */
 function gTranslate($domain = null, $singular, $plural = '', $count = null, $nonetext = '') {
     global $gallery;
@@ -50,29 +50,29 @@ function gTranslate($domain = null, $singular, $plural = '', $count = null, $non
         return $nonetext;
     }
 
-    if (gettext_installed()) {        	
-	$gDomain = $gallery->language. "-gallery_$domain";
-	bindtextdomain($gDomain, dirname(dirname(__FILE__)) . '/locale');
-	textdomain($gDomain);
+    if (gettext_installed()) {
+        $gDomain = $gallery->language. "-gallery_$domain";
+        bindtextdomain($gDomain, dirname(dirname(__FILE__)) . '/locale');
+        textdomain($gDomain);
     }
 
     if(!$plural) {
-    	if (gettext_installed()) {        	
-        	$translation = dgettext($gDomain, $singular);
-    	}
-    	else {
-    		$translation = _($singular);
-    	}
+        if (gettext_installed()) {
+            $translation = dgettext($gDomain, $singular);
+        }
+        else {
+            $translation = _($singular);
+        }
     }
     else {
         if (!empty($count) && intval($count) == 0) {
             $count = 1;
         }
         if (ngettext_installed()) {
-        	$translation = sprintf(dngettext($gDomain, $singular, $plural, $count), $count);
+            $translation = sprintf(dngettext($gDomain, $singular, $plural, $count), $count);
         }
         else {
-        	$translation = sprintf(ngettext($singular, $plural, $count), $count);
+            $translation = sprintf(ngettext($singular, $plural, $count), $count);
         }
     }
     return $translation;
@@ -82,7 +82,7 @@ function gTranslate($domain = null, $singular, $plural = '', $count = null, $non
  * Detect the first Language of users Browser
  * Some Browser only send 2 digits like he or de.
  * This is caught later with the aliases
- * @author Jens Tkotz <jens@peino.de>
+ * @author Jens Tkotz
  * @return string   $browserLang
 */
 function getBrowserLanguage() {
@@ -99,7 +99,8 @@ function getBrowserLanguage() {
         $lang_pieces = explode ("-",$lang[0]);
         if (strlen($lang[0]) >2) {
             $browserLang = strtolower($lang_pieces[0]). "_".strtoupper($lang_pieces[1]) ;
-        } else {
+        }
+        else {
             $browserLang = $lang[0];
         }
     }
@@ -115,15 +116,13 @@ function getBrowserLanguage() {
  * - language
  * - charset
  * - direction
- * - alignment
 */
 function setLangDefaults($nls) {
-	global $gallery;
+    global $gallery;
 
-	$gallery->language 	= 'en_US';
-	$gallery->charset  	= $nls['default']['charset'];
-	$gallery->direction	= $nls['default']['direction'];
-	$gallery->align		= $nls['default']['alignment'];
+    $gallery->language 	= 'en_US';
+    $gallery->charset  	= $nls['default']['charset'];
+    $gallery->direction	= $nls['default']['direction'];
 }
 
 /**
@@ -132,82 +131,83 @@ function setLangDefaults($nls) {
  * @author Jens Tkotz
  */
 function getEnvLang() {
-	global $GALLERY_EMBEDDED_INSIDE_TYPE;
+    global $GALLERY_EMBEDDED_INSIDE_TYPE;
 
-	global $board_config;                       /* Needed for phpBB2    		*/
-	global $_CONF;                              /* Needed for GeekLog   		*/
-	global $mosConfig_locale, $mosConfig_lang;  /* Needed for Mambo / Joomla!	*/
-	global $currentlang;                        /* Needed for CPGNuke		*/
+    global $board_config;                       /* Needed for phpBB2    		*/
+    global $_CONF;                              /* Needed for GeekLog   		*/
+    global $mosConfig_locale, $mosConfig_lang;  /* Needed for Mambo / Joomla!	*/
+    global $currentlang;                        /* Needed for CPGNuke		*/
 
-	$envLang = NULL;
+    $envLang = NULL;
 
-	switch ($GALLERY_EMBEDDED_INSIDE_TYPE) {
-		case 'postnuke':
-			if (!empty($_SESSION['PNSVlang'])) {
-				$envLang = $_SESSION['PNSVlang'];
-			}
-			else  {
-				$envLang = pnSessionGetVar('lang');
-			}
-		break;
+    switch ($GALLERY_EMBEDDED_INSIDE_TYPE) {
+        case 'postnuke':
+            if (!empty($_SESSION['PNSVlang'])) {
+                $envLang = $_SESSION['PNSVlang'];
+            }
+            else  {
+                $envLang = pnSessionGetVar('lang');
+            }
+            break;
 
-		case 'phpnuke':
-		case 'nsnnuke':
-			if (isset($_COOKIE['lang'])) {
-				$envLang = $_COOKIE['lang'];
-			}
-		break;
+        case 'phpnuke':
+        case 'nsnnuke':
+            if (isset($_COOKIE['lang'])) {
+                $envLang = $_COOKIE['lang'];
+            }
+            break;
 
-		case 'phpBB2':
-			if (isset($board_config['default_lang'])) {
-				$envLang = $board_config['default_lang'];
-			}
-		break;
+        case 'phpBB2':
+            if (isset($board_config['default_lang'])) {
+                $envLang = $board_config['default_lang'];
+            }
+            break;
 
-		case 'GeekLog':
-			/* Note: $_CONF is not a Superglobal ;) */
-			if (isset($_CONF['language'])) {
-				$envLang = $_CONF['language'];
-			} else if (isset($_CONF['locale'])) {
-				$envLang = $_CONF['locale'];
-			}
-		break;
+        case 'GeekLog':
+            /* Note: $_CONF is not a Superglobal ;) */
+            if (isset($_CONF['language'])) {
+                $envLang = $_CONF['language'];
+            } else if (isset($_CONF['locale'])) {
+                $envLang = $_CONF['locale'];
+            }
+            break;
 
-		case 'mambo':
-		case 'joomla':
-			$envLang = $mosConfig_lang;
-			/* if Alias and Lang are equal, then now Alias was defined */
-			if (getLanguageAlias($envLang) == $envLang) {
-				if (isset($mosConfig_locale)){
-					$envLang = $mosConfig_locale;
-				}
-			}
-		break;
+        case 'mambo':
+        case 'joomla':
+            $envLang = $mosConfig_lang;
+            /* if Alias and Lang are equal, then now Alias was defined */
+            if (getLanguageAlias($envLang) == $envLang) {
+                if (isset($mosConfig_locale)){
+                    $envLang = $mosConfig_locale;
+                }
+            }
+            break;
 
-		case 'cpgnuke':
-			if (isset($currentlang)){
-				$envLang = $currentlang;
-			}
-		break;
+        case 'cpgnuke':
+            if (isset($currentlang)){
+                $envLang = $currentlang;
+            }
+            break;
 
-		default:
-			$envLang = NULL;
-		break;
-	}
+        default:
+            $envLang = NULL;
+            break;
+    }
 
-	return $envLang;
+    return $envLang;
 }
 
 /**
  * Gets the default language for Gallery.
  * If not set, fallback to browserlanguage.
- * @author Jens Tkotz <jens@peino.de>
+ * @author Jens Tkotz
  * @return string $defaultLanguage;
  */
 function getDefaultLanguage() {
     global $gallery;
-    if(isset($gallery->app->default_language) 
-      && $gallery->app->default_language != 'browser') {
+
+    if(isset($gallery->app->default_language)
+    && $gallery->app->default_language != 'browser') {
         $defaultLanguage = $gallery->app->default_language;
     }
     else {
@@ -224,25 +224,34 @@ function getDefaultLanguage() {
  * Gallery runs in the language the Environment use.
 */
 function forceStaticLang() {
-	global $GALLERY_EMBEDDED_INSIDE_TYPE;
-	global $gallery;
+    global $GALLERY_EMBEDDED_INSIDE_TYPE;
+    global $gallery;
 
-	$useStatic = array('joomla', 'mambo', 'phpBB2', 'GeekLog');
+    $useStatic = array('joomla', 'mambo', 'phpBB2', 'GeekLog');
 
-	if (in_array($GALLERY_EMBEDDED_INSIDE_TYPE, $useStatic)) {
-		$gallery->app->ML_mode = 1;
-	}
-}	
+    if (in_array($GALLERY_EMBEDDED_INSIDE_TYPE, $useStatic)) {
+        $gallery->app->ML_mode = 1;
+    }
+}
 
 /**
  * This function does the initialization of language related things.
- * @author Jens Tkotz <jens@peino.de>
+ * @author Jens Tkotz
  */
-function initLanguage($sendHeader=true) {
+function initLanguage($sendHeader = true) {
     static $languages_initialized = false;
 
     global $gallery, $GALLERY_EMBEDDED_INSIDE, $GALLERY_EMBEDDED_INSIDE_TYPE;
 
+    /**
+     * Init was already done. Just return, or do a reinit
+     * if the giving userlanguage is different than the current language
+    */
+
+    if($languages_initialized) {
+		return;
+    }
+
     /* $locale is *NUKEs locale var*/
     global $locale ;
 
@@ -255,7 +264,7 @@ function initLanguage($sendHeader=true) {
     If so, we skip language settings at all */
 
     /* Mode 0 means no Multilanguage at all. */
-    if (isset($gallery->app->ML_mode) && $gallery->app->ML_mode == 0 && !$languages_initialized) {
+    if (isset($gallery->app->ML_mode) && $gallery->app->ML_mode == 0) {
         /* Maybe PHP has no (n)gettext, then we have to substitute _() and ngettext*/
         if (!gettext_installed()) {
             function _($string) {
@@ -263,10 +272,11 @@ function initLanguage($sendHeader=true) {
             }
         }
         if (!ngettext_installed()) {
-            function ngettext($singular, $quasi_plural,$num=0) {
+            function ngettext($singular, $quasi_plural,$num = 0) {
                 if ($num == 1) {
                     return $singular;
-                } else {
+                }
+                else {
                     return $quasi_plural;
                 }
             }
@@ -297,53 +307,57 @@ function initLanguage($sendHeader=true) {
 
         if (!empty($newlang)) {
             /* Set Language to the User selected language. */
-            $gallery->language=$newlang;
-        } else {
+            $gallery->language = $newlang;
+        }
+        else {
             /** No new language.
 			 * Lets see in which Environment were are and look for a language.
 			 * Lets try to determ the used language
-			 */ 
+			 */
             $gallery->language = getEnvLang();
         }
-    } else {
+    }
+    else {
         /** We're not embedded.
 		 * If we got a ML_mode from config.php we use it
 		 * If not we use Mode 2 (Browserlanguage)
 		 */
         if (isset($gallery->app->ML_mode)) {
             $ML_mode = $gallery->app->ML_mode;
-        } else {
+        }
+        else {
             $ML_mode = 2;
         }
 
         switch ($ML_mode) {
             case 1:
-            /* Static Language */
+                /* Static Language */
                 $gallery->language = getDefaultLanguage();
-            break;
-            
-            case 3:
-            /* Does the user want a new language ?*/
-            if (!empty($newlang)) {
-                /* Set Language to the User selected language.*/
-                $gallery->language = $newlang;
-            } elseif (isset($gallery->session->language)) {
-                /* Maybe we already have a language*/
-                $gallery->language = $gallery->session->language;
-            } else {
-                $gallery->language = getDefaultLanguage();
-            }
-            break;
-            
-            default:
-            /* Use Browser Language or Userlanguage when mode 2 or any other (wrong) mode*/
-            $gallery->browser_language = getBrowserLanguage();
-            $gallery->language = $gallery->browser_language;
+                break;
 
-            if (!empty($gallery->user) && $gallery->user->getDefaultLanguage() != '') {
-                $gallery->language = $gallery->user->getDefaultLanguage();
-            }
-            break;
+            case 3:
+                /* Does the user want a new language ?*/
+                if (!empty($newlang)) {
+                    /* Set Language to the User selected language.*/
+                    $gallery->language = $newlang;
+                }
+                elseif (isset($gallery->session->language)) {
+                    /* Maybe we already have a language*/
+                    $gallery->language = $gallery->session->language;
+                }
+                else {
+                    $gallery->language = getDefaultLanguage();
+                }
+                break;
+
+            default:
+                /* Use Browser Language or Userlanguage when mode 2 or any other (wrong) mode*/
+                $gallery->language = getBrowserLanguage();
+
+                if (!empty($gallery->user) && $gallery->user->getDefaultLanguage() != '') {
+                    $gallery->language = $gallery->user->getDefaultLanguage();
+                }
+                break;
         }
     }
 
@@ -371,7 +385,8 @@ function initLanguage($sendHeader=true) {
     /* locale*/
     if (isset($gallery->app->locale_alias[$gallery->language])) {
         $gallery->locale = $gallery->app->locale_alias["$gallery->language"];
-    } else {
+    }
+    else {
         $gallery->locale = $gallery->language;
     }
 
@@ -379,7 +394,7 @@ function initLanguage($sendHeader=true) {
     $locale = $gallery->locale;
 
     /* Check defaults */
-    $checklist = array('direction', 'charset', 'alignment') ;
+    $checklist = array('direction', 'charset') ;
 
     /**
      * This checks wether the previously defined values are available.
@@ -390,7 +405,8 @@ function initLanguage($sendHeader=true) {
         /* if no ... is given, use default*/
         if ( !isset($nls[$check][$gallery->language])) {
             $gallery->$check = $nls['default'][$check] ;
-        } else {
+        }
+        else {
             $gallery->$check = $nls[$check][$gallery->language] ;
         }
     }
@@ -398,9 +414,10 @@ function initLanguage($sendHeader=true) {
     /* When all is done do the settings*/
 
     /* There was previously a != SUNOS check around the LANG= line.  We've determined that it was
-     probably a bogus bug report, since all documentation says this is fine.*/
+    probably a bogus bug report, since all documentation says this is fine.*/
     putenv("LANG=". $gallery->language);
     putenv("LANGUAGE=". $gallery->language);
+
     /* This line was added in 1.5-cvs-b190 to fix problems on FreeBSD 4.10*/
     putenv("LC_ALL=". $gallery->language);
 
@@ -425,157 +442,174 @@ function initLanguage($sendHeader=true) {
     if (gettext_installed()) {
         bindtextdomain($gallery->language. "-gallery_". where_i_am(), dirname(dirname(__FILE__)) . '/locale');
         textdomain($gallery->language. "-gallery_". where_i_am());
-
-    } elseif (!$languages_initialized) {
-        emulate_gettext();
+    }
+    else {
+        emulate_gettext($languages_initialized);
     }
 
     // We test this separate because ngettext() is only available in PHP >=4.2.0 but _() in all PHP4
-    if (!ngettext_installed() && !$languages_initialized) {
-        emulate_ngettext();
+    if (!ngettext_installed()) {
+        emulate_ngettext($languages_initialized);
     }
 
     $languages_initialized = true;
 }
 
-
 function getTranslationFile() {
 
-	global $gallery;
-	static $translationfile;
+    global $gallery;
+    static $translationfile;
 
-	if (empty($translationfile)) {
-		$filename=dirname(dirname(__FILE__)) . '/locale/' . $gallery->language . '/'. $gallery->language . '-gallery_' .  where_i_am()  . '.po';
-		$translationfile=file($filename);
-	}
+    if (empty($translationfile)) {
+        $filename = dirname(dirname(__FILE__)) . '/locale/' .
+        $gallery->language . '/'.
+        $gallery->language . '-gallery_' .  where_i_am()  . '.po';
+        $translationfile = file($filename);
+    }
 
-return $translationfile;
+    return $translationfile;
 }
 
 /** Substitute ngettext function
  * NOTE: this is the first primitive Step !!
  * It fully ignores the plural definition !!
 */
-function emulate_ngettext() {
+function emulate_ngettext($languages_initialized = false) {
+    global $translation;
+    global $gallery;
 
+    if (in_array($gallery->language,array_keys(gallery_languages())) &&
+        $gallery->language != 'en_US') {
 
-	global $translation;
-	global $gallery;
+        $lines = getTranslationFile();
+        foreach ($lines as $key => $value) {
+            // We trim the String to get rid of cr/lf
+            $value = trim($value);
+            if (stristr($value, "msgid") &&
+                ! stristr($lines[$key-1],"fuzzy") && !stristr($value,"msgid_plural")) {
+                //  echo "\n<br>---SID". $value;
+                //  echo "\n<br>---PID". $lines[$key+1];
+                if (stristr($lines[$key+1],"msgid_plural")) {
+                    $singular_key=substr($value, 7,-1);
+                    $translation[$singular_key]=substr(trim($lines[$key+2]),11,-1);
+                    $plural_key=substr(trim($lines[$key+1]), 14,-1);
+                    $translation[$plural_key]=substr(trim($lines[$key+3]),11,-1);
+                    //	echo "\n<br>SK". $singular_key;
+                    //	echo "\n<br>ST". $translation[$singular_key];
+                    //	echo "\n<br>PK". $plural_key;
+                    //	echo "\n<br>PT". $translation[$plural_key];
+                }
+            }
+        }
+    }
 
-	if (in_array($gallery->language,array_keys(gallery_languages())) &&
-		$gallery->language != 'en_US') {
-		$lines=getTranslationFile();
-		foreach ($lines as $key => $value) {
-		//We trim the String to get rid of cr/lf
-			$value=trim($value);
-			if (stristr($value, "msgid") && ! stristr($lines[$key-1],"fuzzy") && !stristr($value,"msgid_plural")) {
-//				echo "\n<br>---SID". $value;
-//					echo "\n<br>---PID". $lines[$key+1];
-				if (stristr($lines[$key+1],"msgid_plural")) {
-					$singular_key=substr($value, 7,-1);
-					$translation[$singular_key]=substr(trim($lines[$key+2]),11,-1);
-					$plural_key=substr(trim($lines[$key+1]), 14,-1);
-					$translation[$plural_key]=substr(trim($lines[$key+3]),11,-1);
-//	echo "\n<br>SK". $singular_key;
-//	echo "\n<br>ST". $translation[$singular_key];
-//	echo "\n<br>PK". $plural_key;
-//	echo "\n<br>PT". $translation[$plural_key];
-				}
-			}
-		}
-		// Substitute ngettext() function
-		function ngettext($singular, $quasi_plural,$num=0) {
-//			echo "\n<br>----";
-//			echo "\nSL: $singular, PL: $quasi_plural, N: $num";
-			if ($num == 1) {
-				if (! empty($GLOBALS['translation'][$singular])) {
-					return $GLOBALS['translation'][$singular] ;
-				} else {
-					return $singular;
-				}
-			}
-			else {
-				if (! empty($GLOBALS['translation'][$quasi_plural])) {
-					return $GLOBALS['translation'][$quasi_plural] ;
-				}
-				else {
-					return $quasi_plural;
-				}
-			}
-		}
-	}
-	else {
-		// There is no translation file or we are using original (en_US), so just return what we got
-		function ngettext($singular, $quasi_plural,$num=0) {
-			if ($num == 1) {
-				return $singular;
-			} else {
-				return $quasi_plural;
-			}
-		}
-	}
+    // Substitute ngettext() function
+    if(! $languages_initialized) {
+        function ngettext($singular, $quasi_plural, $num = 0) {
+            //  echo "\n<br>----";
+            //  echo "\nSL: $singular, PL: $quasi_plural, N: $num";
+            global $gallery;
+
+            if($gallery->language == 'en_US') {
+                if ($num == 1) {
+                    return $singular;
+                }
+                else {
+                    return $quasi_plural;
+                }
+            }
+            else {
+                if ($num == 1) {
+                    if (! empty($GLOBALS['translation'][$singular])) {
+                        return $GLOBALS['translation'][$singular] ;
+                    }
+                    else {
+                        return $singular;
+                    }
+                }
+                else {
+                    if (! empty($GLOBALS['translation'][$quasi_plural])) {
+                        return $GLOBALS['translation'][$quasi_plural] ;
+                    }
+                    else {
+                        return $quasi_plural;
+                    }
+                }
+            }
+        }
+    }
 }
 
 /**
  *
 */
-function emulate_gettext() {
-	global $translation;
-	global $gallery;
+function emulate_gettext($languages_initialized) {
+    global $translation;
+    global $gallery;
 
-	if (in_array($gallery->language,array_keys(gallery_languages())) &&
-		$gallery->language != 'en_US') {
-		$filename=dirname(dirname(__FILE__)) . '/locale/' . $gallery->language . '/'. $gallery->language . '-gallery_' .  where_i_am()  . '.po';
-		$lines=file($filename);
+    if (in_array($gallery->language,array_keys(gallery_languages())) &&
+        $gallery->language != 'en_US') {
 
-		foreach ($lines as $key => $value) {
-			/* We trim the String to get rid of cr/lf */
-			$value=trim($value);
-			if (stristr($value, "msgid") 
-				&& ! stristr($lines[$key-1],"fuzzy") 
-				&& ! stristr($lines[$key],"msgid_plural")
-				&& ! stristr($value,"msgid_plural")) {
-				$new_key=substr($value, 7,-1);
-				$translation[$new_key] = substr(trim($lines[$key+1]),8,-1);
-//		echo "\n<br>NK". $new_key;
-//		echo "\n<br>NT". $translation[$new_key];
-			}
-		}
-		// Substitute _() gettext function
-		function _($search) {
-			if (! empty($GLOBALS['translation'][$search])) {
-				return $GLOBALS['translation'][$search] ;
-			}
-			else {
-				return $search;
-			}
-		}
-	}
-	// There is no translation file or we are using original (en_US), so just return what we got
-	else {
-		function _($search) {
-			return $search;
-		}
-	}
+        $filename = dirname(dirname(__FILE__)) . '/locale/' .
+        $gallery->language . '/'.
+        $gallery->language . '-gallery_' .  where_i_am()  . '.po';
+
+        $lines = file($filename);
+
+        foreach ($lines as $key => $value) {
+            /* We trim the String to get rid of cr/lf */
+            $value = trim($value);
+            if (stristr($value, "msgid") &&
+                ! stristr($lines[$key-1],"fuzzy") &&
+                ! stristr($lines[$key],"msgid_plural") &&
+                ! stristr($value,"msgid_plural")) {
+
+                $new_key = substr($value, 7,-1);
+                $translation[$new_key] = substr(trim($lines[$key+1]),8,-1);
+                //  echo "\n<br>NK". $new_key;
+                //  echo "\n<br>NT". $translation[$new_key];
+            }
+        }
+    }
+
+    // Substitute _() gettext function
+    if(! $languages_initialized) {
+        function _($search) {
+            global $gallery;
+
+            if($gallery->language == 'en_US') {
+                return $search;
+            }
+            else {
+
+                if (! empty($GLOBALS['translation'][$search])) {
+                    return $GLOBALS['translation'][$search] ;
+                }
+                else {
+                    return $search;
+                }
+            }
+        }
+    }
 }
 
 function gettext_installed() {
-	if (in_array("gettext", get_loaded_extensions()) && function_exists('gettext') && function_exists('_')) {
-		return true;
-	}
-	else {
-		return false;
-	}
+    if (in_array("gettext", get_loaded_extensions()) && function_exists('gettext') && function_exists('_')) {
+        return true;
+    }
+    else {
+        return false;
+    }
 }
 
 function ngettext_installed() {
-	if (in_array("ngettext", get_loaded_extensions()) || 
-	  (function_exists('ngettext') && function_exists('dngettext'))) {
-		return true;
-	}
-	else {
-		return false;
-	}
+    if (in_array("ngettext", get_loaded_extensions()) ||
+    (function_exists('ngettext') && function_exists('dngettext'))) {
+        return true;
+    }
+    else {
+        return false;
+    }
 }
 
 /**
@@ -583,8 +617,8 @@ function ngettext_installed() {
  * @author Jens Tkotz
  */
 function gallery_languages() {
-	$nls = getNLS();
-	return $nls['language'];
+    $nls = getNLS();
+    return $nls['language'];
 }
 
 /**
@@ -598,7 +632,7 @@ function getLanguageAlias($language) {
     $nls = getNLS();
 
     if (isset($nls['alias'][$language])) {
-	   return $nls['alias'][$language];
+        return $nls['alias'][$language];
     } else {
         return $language;
     }
@@ -608,37 +642,37 @@ function getLanguageAlias($language) {
  * returns all language relative that gallery could collect.
  */
 function getNLS() {
-	static $nls;
+    static $nls;
 
-	if (empty($nls)) {
-		$nls = array();
-		// Load defaults
-		include (dirname(dirname(__FILE__)) . '/nls.php');
+    if (empty($nls)) {
+        $nls = array();
+        // Load defaults
+        include (dirname(dirname(__FILE__)) . '/nls.php');
 
-		$modules = array('config','core');
-		$dir = dirname(dirname(__FILE__)) . '/locale';
-		if (fs_is_dir($dir) && is_readable($dir) && $handle = fs_opendir($dir)) {
-			while ($dirname = readdir($handle)) {
-				if (ereg("^([a-z]{2}_[A-Z]{2})", $dirname)) {
-					$locale = $dirname;
-					$fc = 0;
-					foreach ($modules as $module) {
-						if (gettext_installed()) {
-							if (fs_file_exists(dirname(dirname(__FILE__)) . "/locale/$dirname/$locale-gallery_$module.po")) $fc++;
-						} else {
-							if (fs_file_exists(dirname(dirname(__FILE__)) . "/locale/$dirname/LC_MESSAGES/$locale-gallery_$module.mo")) $fc++;
-						}
-					}
-					if (fs_file_exists(dirname(dirname(__FILE__)) . "/locale/$dirname/$locale-nls.php") && $fc==sizeof($modules)) {
-						include (dirname(dirname(__FILE__)) . "/locale/$dirname/$locale-nls.php");
-					}
-				}
-			}
-			closedir($handle);
-		}
-	}
+        $modules = array('config','core');
+        $dir = dirname(dirname(__FILE__)) . '/locale';
+        if (fs_is_dir($dir) && is_readable($dir) && $handle = fs_opendir($dir)) {
+            while ($dirname = readdir($handle)) {
+                if (ereg("^([a-z]{2}_[A-Z]{2})", $dirname)) {
+                    $locale = $dirname;
+                    $fc = 0;
+                    foreach ($modules as $module) {
+                        if (gettext_installed()) {
+                            if (fs_file_exists(dirname(dirname(__FILE__)) . "/locale/$dirname/$locale-gallery_$module.po")) $fc++;
+                        } else {
+                            if (fs_file_exists(dirname(dirname(__FILE__)) . "/locale/$dirname/LC_MESSAGES/$locale-gallery_$module.mo")) $fc++;
+                        }
+                    }
+                    if (fs_file_exists(dirname(dirname(__FILE__)) . "/locale/$dirname/$locale-nls.php") && $fc==sizeof($modules)) {
+                        include (dirname(dirname(__FILE__)) . "/locale/$dirname/$locale-nls.php");
+                    }
+                }
+            }
+            closedir($handle);
+        }
+    }
 
-	return $nls;
+    return $nls;
 }
 
 function i18n($buf) {
@@ -646,56 +680,59 @@ function i18n($buf) {
 }
 
 function isSupportedCharset($charset) {
-	$supportedCharsets=array(
-		'UTF-8',
-		'ISO-8859-1',
-		'ISO-8859-15',
-		'cp1252',
-		'BIG5',
-		'GB2312',
-		'BIG5-HKSCS',
-		'Shift_JIS',
-		'EUC-JP'
-	);
+    $supportedCharsets = array(
+        'UTF-8',
+        'ISO-8859-1',
+        'ISO-8859-15',
+        'cp1252',
+        'BIG5',
+        'GB2312',
+        'BIG5-HKSCS',
+        'Shift_JIS',
+        'EUC-JP'
+    );
 
-	$supportedCharsetsNewerPHP=array(
-		'cp866',
-		'cp1251',
-		'KOI8-R'
-	);
+    $supportedCharsetsNewerPHP=array(
+        'cp866',
+        'cp1251',
+        'KOI8-R'
+    );
 
-	/**
+    /**
      * Check if we are using PHP >= 4.1.0
      * If yes, we can use 3rd Parameter so e.g. titles in chinese BIG5 or UTF8 are displayed correct.
      * Otherwise they are messed.
      * Not all Gallery Charsets are supported by PHP, so only thoselisted are recognized.
      */
-	if (function_exists('version_compare')) {
-		if ( (version_compare(phpversion(), "4.1.0", ">=") && in_array($charset, $supportedCharsets)) ||
-		     (version_compare(phpversion(), "4.3.2", ">=") && in_array($charset, $supportedCharsetsNewerPHP)) ) {
-			return true;
-		} else {
-			/* Unsupported Charset*/
-			return false;
-		}
-	} else {
-		/* PHP too old*/
-		return false;
-	}
+    if (function_exists('version_compare')) {
+        if ( (version_compare(phpversion(), "4.1.0", ">=") && in_array($charset, $supportedCharsets)) ||
+        (version_compare(phpversion(), "4.3.2", ">=") && in_array($charset, $supportedCharsetsNewerPHP)) ) {
+            return true;
+        }
+        else {
+            /* Unsupported Charset*/
+            return false;
+        }
+    }
+    else {
+        /* PHP too old*/
+        return false;
+    }
 }
-	
+
 /**
  * Gallery Version of htmlentities
- * Enhancement: Depending on PHP Version and Charset use 
+ * Enhancement: Depending on PHP Version and Charset use
  * optional 3rd Parameter of php's htmlentities
  */
 function gallery_htmlentities($string) {
-	global $gallery;
+    global $gallery;
 
-	if (isSupportedCharset($gallery->charset)) {
-		return htmlentities($string,ENT_COMPAT ,$gallery->charset);
-	} else {
-		return htmlentities($string);
+    if (isSupportedCharset($gallery->charset)) {
+        return htmlentities($string,ENT_COMPAT ,$gallery->charset);
+    }
+    else {
+        return htmlentities($string);
     }
 }
 
@@ -703,37 +740,40 @@ function gallery_htmlentities($string) {
  * Convert all HTML entities to their applicable characters
  */
 function unhtmlentities($string) {
-	global $gallery;
+    global $gallery;
 
-	if (empty($string)) {
-		return '';
-	}
+    if (empty($string)) {
+        return '';
+    }
 
-	if (function_exists('html_entity_decode')) {
-		$nls = getNLS();
-		if (isset ($nls['charset'][$gallery->language])) {
-			$charset = $nls['charset'][$gallery->language];
-		} else {
-			$charset = $nls['default']['charset'];
-		}
+    if (function_exists('html_entity_decode')) {
+        $nls = getNLS();
 
-		if (isSupportedCharset($charset) && strtolower($charset) != 'utf-8') {
-			$return = html_entity_decode($string,ENT_COMPAT ,$charset);
-		}
-		else {
-			// For unsupported charsets you may do this:
-			$trans_tbl = get_html_translation_table (HTML_ENTITIES);
-			$trans_tbl = array_flip ($trans_tbl);
-			$return = strtr ($string, $trans_tbl);
-		}
-	} else {
-		// For users with PHP prior to 4.3.0 you may do this:
-		$trans_tbl = get_html_translation_table (HTML_ENTITIES);
-		$trans_tbl = array_flip ($trans_tbl);
-		$return = strtr ($string, $trans_tbl);
-	}
+        if (isset ($nls['charset'][$gallery->language])) {
+            $charset = $nls['charset'][$gallery->language];
+        }
+        else {
+            $charset = $nls['default']['charset'];
+        }
 
-return $return;
+        if (isSupportedCharset($charset) && strtolower($charset) != 'utf-8') {
+            $return = html_entity_decode($string,ENT_COMPAT ,$charset);
+        }
+        else {
+            // For unsupported charsets you may do this:
+            $trans_tbl = get_html_translation_table (HTML_ENTITIES);
+            $trans_tbl = array_flip ($trans_tbl);
+            $return = strtr ($string, $trans_tbl);
+        }
+    }
+    else {
+        // For users with PHP prior to 4.3.0 you may do this:
+        $trans_tbl = get_html_translation_table (HTML_ENTITIES);
+        $trans_tbl = array_flip ($trans_tbl);
+        $return = strtr ($string, $trans_tbl);
+    }
+
+    return $return;
 }
 
 /**
@@ -744,23 +784,23 @@ return $return;
  */
 function automaticFieldsList() {
     return array(
-        'Upload Date'   => gTranslate('common', "Upload Date"),
-        'Capture Date' 	=> gTranslate('common', "Capture Date"),
-        'Dimensions' 	=> gTranslate('common', "Image Size"),
-        'EXIF'          => gTranslate('common', "Additional EXIF Data"));
+        'Upload Date'   => gTranslate('common', "Upload date"),
+        'Capture Date' 	=> gTranslate('common', "Capture date"),
+        'Dimensions' 	=> gTranslate('common', "Image size"),
+        'EXIF'          => gTranslate('common', "Additional EXIF data"));
 }
 
 /** These are custom fields which can be entered manual by the User
  * Since they are used often, we translated them.
  */
 function translateableFields() {
-	return array(
-		'title'		=> gTranslate('common', "title"),
-		'Title'		=> gTranslate('common', "Title"),
-		'Description'	=> gTranslate('common', "Description"),
-		'description'	=> gTranslate('common', "description"),
-		'AltText'	=> gTranslate('common', "Alt Text / onMouseOver"),
-	);
+    return array(
+        'title'			=> gTranslate('common', "title"),
+        'Title'			=> gTranslate('common', "Title"),
+        'Description'	=> gTranslate('common', "Description"),
+        'description'	=> gTranslate('common', "description"),
+        'AltText'		=> gTranslate('common', "Alt text / Tooltip"),
+    );
 }
 
 /**
@@ -834,9 +874,9 @@ function languageSelector() {
                 }
                 else {
                     $langSelectTable->addElement(array(
-			'content' => $flagImage,
-			'cellArgs' => array('style' => 'padding-bottom:10px')
-		    ));
+                    'content' => $flagImage,
+                    'cellArgs' => array('style' => 'padding-bottom:10px')
+                    ));
                 }
             }
         }
@@ -865,10 +905,10 @@ function langLeft() {
     global $gallery;
 
     if ($gallery->direction == 'ltr') {
-	return 'left';
+        return 'left';
     }
     else {
-	return 'right';
+        return 'right';
     }
 }
 
@@ -877,13 +917,13 @@ function langLeft() {
  * @author Jens Tkotz
  */
 function langRight() {
-	global $gallery;
+    global $gallery;
 
-	if ($gallery->direction == 'ltr') {
-		return 'right';
-	}
-	else {
-		return 'left';
-	}
+    if ($gallery->direction == 'ltr') {
+        return 'right';
+    }
+    else {
+        return 'left';
+    }
 }
 ?>
\ No newline at end of file
