@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2006 Bharat Mediratta
+ * Copyright (C) 2000-2007 Bharat Mediratta
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: url.php 14310 2006-08-14 07:41:08Z jenst $
+ * $Id: url.php 15916 2007-03-04 18:54:06Z jenst $
  */
 ?>
 <?php
@@ -60,9 +60,11 @@ function getGalleryBaseUrl() {
     }
     elseif(where_i_am() == 'config') {
         $base = '..';
-    } elseif (defined('GALLERY_URL')) {
+    }
+    elseif (defined('GALLERY_URL')) {
         $base = GALLERY_URL;
-    } else {
+    }
+    else {
         $base = '.';
     }
 
@@ -89,11 +91,15 @@ function makeGalleryUrl($target = '', $args = array()) {
 	global $GALLERY_MODULENAME;
 	global $modpath;
 
-        if (empty($GALLERY_MODULENAME)
-          && $GALLERY_EMBEDDED_INSIDE =='nuke'
-          && !empty($modpath)) {
-            $GALLERY_MODULENAME = basename(dirname($modpath));
-        }
+	if (empty($GALLERY_MODULENAME) &&
+		$GALLERY_EMBEDDED_INSIDE =='nuke' &&
+		!empty($modpath))
+	{
+		$GALLERY_MODULENAME = basename(dirname($modpath));
+	}
+
+	/* Needed for postNuke (0.8 and above) */
+	global $GALLERY_POSTNUKE_VERSION;
 
 	/* Needed for phpBB2 */
 	global $userdata;
@@ -111,7 +117,13 @@ function makeGalleryUrl($target = '', $args = array()) {
 
 	if(!urlIsRelative($gallery->app->photoAlbumURL)) {
 		$gUrl = parse_url($gallery->app->photoAlbumURL);
-		$urlprefix = $gUrl['scheme'] .'://'. $gUrl['host'];
+
+		if(isset($gUrl['port'])) {
+			$urlprefix = $gUrl['scheme'] .'://'. $gUrl['host'] . ':' . $gUrl['port'];
+		}
+		else {
+			$urlprefix = $gUrl['scheme'] .'://'. $gUrl['host'];
+		}
 	}
 	else {
 	    $urlprefix = '';
@@ -163,7 +175,7 @@ function makeGalleryUrl($target = '', $args = array()) {
 			break;
 
 			case 'postnuke':
-				if (substr(_PN_VERSION_NUM, 0, 7) < "0.7.6.0") {
+				if (substr($GALLERY_POSTNUKE_VERSION, 0, 7) < "0.7.6.0") {
 					$args["op"] = "modload";
 					$args["file"] = "index";
 
