@@ -1,23 +1,23 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2006 Bharat Mediratta
- * 
+ * Copyright (C) 2000-2007 Bharat Mediratta
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: valchecks.php 13579 2006-05-02 09:59:13Z jenst $
+ * $Id: valchecks.php 16697 2007-06-28 10:31:31Z jenst $
  */
 ?>
 <?php
@@ -43,7 +43,7 @@ function sanityCheck($var, $type, $default = NULL, $choices = array()) {
                 return array(0, $var, '');
             }
             else {
-                return array(2, $var, _("The given frame is not valid."));
+                return array(2, $var, gTranslate('common', "The given frame is not valid."));
             }
             break;
         case 'inChoice':
@@ -51,10 +51,10 @@ function sanityCheck($var, $type, $default = NULL, $choices = array()) {
                 return array(0, $var, '');
             }
             elseif (isset($default)) {
-                return array(1, $default, _("Value was set to given default. Because the original value is not a in the allowed amount of choices."));
+                return array(1, $default, gTranslate('common', "Value was set to given default, because the original value is not in the allowed list of choices."));
             }
             else {
-                return array(2, $var, _("The given value is not in the allowed amount of choices."));
+                return array(2, $var, gTranslate('common', "The given value is not in the allowed list of choices."));
             }
             break;
         default:
@@ -80,22 +80,24 @@ function isValidInteger($mixed, $includingZero = false, $default = NULL, $emptyA
     $minimum = ($includingZero == true) ? 0 : 1;
 
     if ( $mixed == '' && $emptyAllowed) {
-	return array(0, $mixed, '');
+        return array(0, $mixed, '');
     }
-	
+
     if (! is_numeric($mixed)) {
-	if (isset($default)) {
-	    return array(1,$default, _("Value was set to given default. Because the original value is not numeric."));
-	} else {
-	    return array(2, false, _("The given Value is not numeric."));
-	}
+        if (isset($default)) {
+            return array(1, $default, gTranslate('common', "Value was set to given default, because the original value is not numeric."));
+        }
+        else {
+            return array(2, false, gTranslate('common', "The given value is not numeric."));
+        }
     }
 
     if($mixed < $minimum) {
-	if (isset($default)) {
-            return array(1, $default, _("Value was set to given default. Because the original value is not a valid Integer"));
-        } else {
-            return array(2, false, _("The given Value not a valid Integer."));
+        if (isset($default)) {
+            return array(1, $default, gTranslate('common', "Value was set to given default, because the original value is not a valid integer."));
+        }
+        else {
+            return array(2, false, gTranslate('common', "The given value not a valid integer."));
         }
     }
 
@@ -104,12 +106,13 @@ function isValidInteger($mixed, $includingZero = false, $default = NULL, $emptyA
 
 function isValidText($text, $default = NULL) {
     $sanitized = sanitizeInput($text);
+
     if($sanitized != $text) {
         if(isset($default)) {
-            return array(1, $default, _("Value was set to given default. Because the original value is not a valid text"));
+            return array(1, $default, gTranslate('common', "Value was set to given default, because the original value is not a valid text."));
         }
         else {
-            return array(1, $sanitized, _("Value was corrected, because the original value is not a valid text"));
+            return array(1, $sanitized, gTranslate('common', "Value was corrected, because the original value is not a valid text."));
         }
     }
     else {
