@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2006 Bharat Mediratta
+ * Copyright (C) 2000-2007 Bharat Mediratta
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: voting.php 14292 2006-08-13 05:02:55Z jenst $
+ * $Id: voting.php 16794 2007-07-30 05:41:01Z jenst $
  */
 ?>
 <?php
@@ -128,23 +128,28 @@ function getVotingID() {
 
 }
 
-function canVote()
-{
+function canVote() {
 	global $gallery;
+	static $canVote;
+
+	if(isset($canVote)) {
+		return $canVote;
+	}
 
 	if ($gallery->album->numPhotos($gallery->user->canWriteToAlbum($gallery->album)) == 0) {
-	       return false;
+	       $canVote = false;
+	}
+	else if ($gallery->album->getVoterClass() == "Everybody") {
+		$canVote = true;
+	}
+	elseif ($gallery->album->getVoterClass() == "Logged in" && $gallery->user->isLoggedIn()) {
+		$canVote = true;
+	}
+	else {
+		$canVote = false;
 	}
 
-	if ($gallery->album->getVoterClass() == "Everybody") {
-		return true;
-	}
-
-	if ($gallery->album->getVoterClass() == "Logged in" && $gallery->user->isLoggedIn()) {
-		return true;
-	}
-
-	return false;
+	return $canVote;
 }
 
 function addPolling ($id, $form_pos=-1, $immediate=true) {
