@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2006 Bharat Mediratta
+ * Copyright (C) 2000-2007 Bharat Mediratta
  *
  * This file originally by Vallimar.
  * 
@@ -19,7 +19,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: register.php 13338 2006-03-27 15:32:14Z jenst $
+ * $Id: register.php 15632 2007-01-02 06:01:08Z jenst $
  */
 ?>
 <?php
@@ -34,17 +34,17 @@ doctype();
 ?>
 <html>
 <head>
-  <title><?php echo sprintf(_("Register new user for '%s'"), $gallery->app->galleryTitle) ?></title>
+  <title><?php printf(gTranslate('core', "Register new user for '%s'"), $gallery->app->galleryTitle) ?></title>
   <?php common_header(); ?>
 </head>
 <body dir="<?php echo $gallery->direction ?>" class="popupbody">
-<div class="popuphead"><?php echo sprintf(_("Register new user for '%s'"), $gallery->app->galleryTitle) ?></div>
-  <div class="popup" align="center">
+<div class="popuphead"><?php echo sprintf(gTranslate('core', "Register new user for '%s'"), $gallery->app->galleryTitle) ?></div>
+  <div class="popup">
 <?php if ($gallery->app->selfReg != 'yes' || $gallery->app->emailOn == 'no') { ?>
 	<p>
-	<?php echo _("This Gallery does not support self-registration by visitors.") ?>
+	<?php echo gTranslate('core', "This Gallery does not support self-registration by visitors.") ?>
 	<br><br>
-	<form> <input type="button" value="<?php echo _("Dismiss") ?>" onclick='parent.close()'> </form>
+	<form> <input type="button" value="<?php echo gTranslate('core', "Dismiss") ?>" onclick='parent.close()'> </form>
   </div>
 </body>
 </html>
@@ -59,14 +59,14 @@ $allowChange['fullname'] = true;
 $allowChange['email'] = true;
 $allowChange['default_language'] = true;
 $allowChange['create_albums'] = false;
-$allowChange["send_email"] = false;
-$allowChange["member_file"] = false;
+$allowChange['send_email'] = false;
+$allowChange['member_file'] = false;
 
 $errorCount = 0;
 if (!empty($formaction) && $formaction == 'create') {
 	// Security check.
         if($fullname != strip_tags($fullname)) {
-            $gErrors["fullname"] = _("Your fullname containes invalid data!");
+            $gErrors["fullname"] = gTranslate('core', "Your fullname containes invalid data!");
             $errorCount++;
         }
 
@@ -77,12 +77,12 @@ if (!empty($formaction) && $formaction == 'create') {
 	}
 
 	if (empty($fullname) || !strcmp($fullname, '')) {
-		$gErrors['fullname'] = _("You must specify a name.");
+		$gErrors['fullname'] = gTranslate('core', "You must specify a name.");
 		$errorCount++;
 	}
 
 	if (!check_email($email)) {
-		$gErrors['email'] = _("You must specify a valid email address.");
+		$gErrors['email'] = gTranslate('core', "You must specify a valid email address.");
 		$errorCount++;
 	}
 
@@ -104,24 +104,25 @@ if (!empty($formaction) && $formaction == 'create') {
 	       ereg_replace("!!NEWPASSWORDLINK!!",
 	       $tmpUser->genRecoverPasswordHash(),
 	        welcome_email()))));
-	    $logmsg = sprintf(_("%s has registered.  Email has been sent to %s."), $uname, $email);
+	    $logmsg = sprintf(gTranslate('core', "%s has registered.  Email has been sent to %s."), $uname, $email);
 	    $logmsg2  = sprintf("%s has registered.  Email has been sent to %s.", $uname, $email);
 	    if ($logmsg != $logmsg2) {
 	        $logmsg .= " <<<<>>>>> $logmsg2";
 	    }
 
-	    if (gallery_mail($email, _("Gallery Self Registration"),$msg, $logmsg)) {
+	    if (gallery_mail($email, gTranslate('core', "Gallery Self Registration"),$msg, $logmsg)) {
 	        $tmpUser->save();
-	        echo "<p>".sprintf(_("An email has been sent to %s."), $email);
+	        echo "<p>".sprintf(gTranslate('core', "An email has been sent to %s."), $email);
 	        echo '<br>';
-	        echo _("Your account information is contained within the email.");
+	        echo gTranslate('core', "Your account information is contained within the email.");
 	    } else {
-	        echo gallery_error(_("Email could not be sent.  Please contact gallery administrator to register on this site"));
+	        echo gallery_error(gTranslate('core', "Email could not be sent.  Please contact gallery administrator to register on this site"));
 	    }
 ?>
-		<br><br>
-		<form> <input type="button" value="<?php echo _("Dismiss") ?>" onclick='parent.close()'> </form>
+		<center>
+		<input type="button" value="<?php echo gTranslate('core', "Dismiss") ?>" onclick='parent.close()'>
 		</center>
+		</div>
 		</body>
 		</html>
 <?php
@@ -135,11 +136,13 @@ echo makeFormIntro('register.php', array(
 include(dirname(__FILE__) . '/html/userData.inc');
 ?>
 <p>
-<?php echo _("Your account information will be sent to the email address you provide.") ?>
-<br><br>
+<?php echo gTranslate('core', "Your account information will be sent to the email address you provide.") ?>
+<br>
+<center>
 <input type="hidden" name="formaction" value="">
-<input type="submit" name="create" value="<?php echo _("Send request") ?>" onclick="usercreate_form.formaction.value ='create'">
-<input type="submit" name="cancel" value="<?php echo _("Cancel") ?>" onclick='parent.close()'>
+<input type="submit" name="create" value="<?php echo gTranslate('core', "Send request") ?>" onclick="usercreate_form.formaction.value ='create'">
+<input type="submit" name="cancel" value="<?php echo gTranslate('core', "Cancel") ?>" onclick='parent.close()'>
+</center>
 </form>
 <script language="javascript1.2" type="text/JavaScript">
 <!--
