@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2006 Bharat Mediratta
+ * Copyright (C) 2000-2007 Bharat Mediratta
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: check_netpbm.php 13338 2006-03-27 15:32:14Z jenst $
+ * $Id: check_netpbm.php 16697 2007-06-28 10:31:31Z jenst $
  */
 ?>
 <?php 
@@ -25,12 +25,12 @@
 ?>
 <html>
 <head>
-	<title><?php echo _("Gallery NetPBM Check") ?></title>
+	<title><?php echo _("Gallery Netpbm Check") ?></title>
 	<?php echo getStyleSheetLink() ?>
 </head>
 <body dir="<?php echo $gallery->direction ?>">
 <?php configLogin(basename(__FILE__)); ?>
-<?php $app_name='NetPBM' ?>
+<?php $app_name='Netpbm' ?>
 
 <h1 class="header"><?php echo sprintf(_("Check %s"), $app_name) ?></h1>
 
@@ -143,10 +143,10 @@ if (gallerySanityCheck() != NULL) {
 				<p><?php
 				if (!empty($show_details)) {
 					print sprintf(_("%sClick here%s to hide the details"), 
-						'<a href="check_netpbm.php?show_details=0">','</a>');
+						'<a href="check_Netpbm.php?show_details=0">','</a>');
 				} else {
 					print sprintf(_("If you see errors, you should %sclick here%s to see more details"),
-						'<a href="check_netpbm.php?show_details=1">','</a>');
+						'<a href="check_Netpbm.php?show_details=1">','</a>');
 				}
 ?>				
 				</p>
@@ -173,7 +173,7 @@ $binaries = array("giftopnm",
 	    );
 
 foreach ($binaries as $bin) {
-	$result=checkNetPbm($bin);
+	$result=checkNetpbm($bin);
 	if (isset($result['details'])) {
 		$width_1col="30%";
 	} else {
@@ -236,7 +236,7 @@ if (fs_file_exists($debugfile)) {
 </html>
 <?php
 
-function checkNetPbm($cmd) {
+function checkNetpbm($cmd) {
 	global $gallery;
 	global $show_details;
 	global $debugfile;
@@ -281,7 +281,7 @@ function checkNetPbm($cmd) {
 					$linecount++;
 					$buf = fgets($fd, 4096);
 					if ($linecount == 1) {
-			    			if (eregi("using lib(pbm|netpbm) from netpbm version: netpbm (.*)[\n\r]$",  $buf, $regs)) {
+			    			if (eregi("using lib(pbm|Netpbm) from Netpbm version: Netpbm (.*)[\n\r]$",  $buf, $regs)) {
 							$version = $regs[1];
 						} else {
 							$result['error'] = $buf;
