@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2006 Bharat Mediratta
+ * Copyright (C) 2000-2007 Bharat Mediratta
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: stats-wizard.php 13338 2006-03-27 15:32:14Z jenst $
+ * $Id: stats-wizard.php 16803 2007-08-01 20:49:39Z jenst $
  *
  */
 ?>
@@ -51,8 +51,8 @@ if (!$GALLERY_EMBEDDED_INSIDE) {
     includeHtmlWrap("gallery.header");
 
     $adminbox['text'] ='<span class="head">'. _("Gallery statistics - Wizard") .'</span>';
-    $adminCommands = '[<a href="'. makeGalleryUrl("admin-page.php") .'">'. _("return to admin page") .'</a>] ';
-    $adminCommands .= '[<a href="'. makeAlbumUrl() .'">'. _("return to gallery") .'</a>] ';
+    $adminCommands = '[<a href="'. makeGalleryUrl("admin-page.php") .'">'. _("Return to admin page") .'</a>] ';
+    $adminCommands .= '[<a href="'. makeAlbumUrl() .'">'. _("Return to gallery") .'</a>] ';
 
     $adminbox["commands"] = $adminCommands;
     $adminbox["bordercolor"] = $gallery->app->default["bordercolor"];
