@@ -50,7 +50,7 @@
  * Copyright (C) 2004 Jeremy Gilliat with rating contribution by Haplo
  * based on Bharat Mediratta's standard Gallery code.
  *
- * $Id: stats.php 12188 2005-12-04 19:43:46Z jenst $
+ * $Id: stats.php 16803 2007-08-01 20:49:39Z jenst $
  */
 
 require_once(dirname(__FILE__) . '/init.php');
@@ -76,62 +76,62 @@ $reverse = (bool)$reverse;
 switch ($type) {
     case 'votes':
         if ($reverse) {
-            $stats_title =  _(" - Images with the least votes");
+            $stats_title =  gTranslate('core', " - Images with the least votes");
         }
         else {
-            $stats_title =  _(" - Images with the most votes");
+            $stats_title =  gTranslate('core', " - Images with the most votes");
         }
     break;
 
     case 'ratings':
         if ($reverse ) {
-            $stats_title =  _(" - Bottom rated images");
+            $stats_title =  gTranslate('core', " - Bottom rated images");
         }
     else {
-            $stats_title =  _(" - Top rated images");
+            $stats_title =  gTranslate('core', " - Top rated images");
     }
     break;
 
     case 'date':
         if ($reverse ) {
-            $stats_title =  _(" - Oldest images first");
+            $stats_title =  gTranslate('core', " - Oldest images first");
         }
         else {
 
-            $stats_title =  _(" - Latest added images");
+            $stats_title =  gTranslate('core', " - Latest added images");
         }
     break;
 
     case 'cdate':
         if ($reverse ) {
-            $stats_title =  _(" - Oldest Capture Date");
+            $stats_title =  gTranslate('core', " - Oldest Capture Date");
         }
         else {
-            $stats_title =  _(" - Latest Capture Date");
+            $stats_title =  gTranslate('core', " - Latest Capture Date");
         }
     break;
 
     case 'comments':
         if ($reverse ) {
-            $stats_title =  _(" - Oldest Comments");
+            $stats_title =  gTranslate('core', " - Oldest Comments");
         }
         else {
-            $stats_title =  _(" - Latest Comments");
+            $stats_title =  gTranslate('core', " - Latest Comments");
         }
     break;
 
     case 'random':
-        $stats_title =  _(" - Random Images");
+        $stats_title =  gTranslate('core', " - Random Images");
     break;
 
     default:
     // 'views'
     $type = 'views';
     if ($reverse ) {
-        $stats_title =  _(" - Images with the least views");
+        $stats_title =  gTranslate('core', " - Images with the least views");
     }
     else {
-        $stats_title =  _(" - Images with the most views");
+        $stats_title =  gTranslate('core', " - Images with the most views");
     }
     break;
 }
@@ -303,7 +303,7 @@ for ($i = 1; $i <= $numTopAlbums; $i++) {
 
 $numAlbums = count($list);
 
-debugMessage(sprintf (_("Number Albums = %s") . "<br>", $numAlbums),__FILE__ , __LINE__) ;
+debugMessage(sprintf (gTranslate('core', "Number Albums = %s") . "<br>", $numAlbums),__FILE__ , __LINE__) ;
 
 $skip = array();
 $arrPhotos = array();
@@ -314,7 +314,7 @@ $cacheReloadRequired = false;
 // Attempt to load from cache if cache is selected
 // and a period or album have not been specified.
 $cacheFilename = $gallery->app->albumDir . "/stats.$type.$reverse.cache";
-debugMessage(sprintf (_("Cache filename = %s ; enabled = %s ; expires = %s"), $cacheFilename, $cache->enabled, $cache->expireSecs), __FILE__, __LINE__);
+debugMessage(sprintf (gTranslate('core', "Cache filename = %s ; enabled = %s ; expires = %s"), $cacheFilename, $cache->enabled, $cache->expireSecs), __FILE__, __LINE__);
 
 if (!isset($refreshcache) &&
     !isset($period) &&
@@ -325,7 +325,7 @@ if (!isset($refreshcache) &&
         $cacheTime = $cacheState[9];
         if ($cache->expireSecs == -1 ||
         time() - $cacheTime < $cache->expireSecs) {
-            debugMessage(sprintf (_("Time now = %s ; Cache time = %s"), time(), $cacheTime), __FILE__, __LINE__);
+            debugMessage(sprintf (gTranslate('core', "Time now = %s ; Cache time = %s"), time(), $cacheTime), __FILE__, __LINE__);
             $numPhotos = readCacheNumPhotos($cacheFilename);
             if ($numPhotos != -1 ) {
                 $arrPhotos = array_fill(0, $numPhotos, 0);
@@ -340,14 +340,14 @@ if (!isset($refreshcache) &&
 
     // Logged in users don't use the cache
     if ($gallery->user->isLoggedIn()) {
-        debugMessage(_("Logged In - Disabling Cache"), __FILE__, __LINE__);
+        debugMessage(gTranslate('core', "Logged In - Disabling Cache"), __FILE__, __LINE__);
         $refreshcache = false;
         $useCache = false;
     }
 }
 
-debugMessage((!empty($useCache)) ? _("Using cache") : _("Not using cache") ,__FILE__, __LINE__);
-debugMessage((!empty($refreshcache)) ? _("Cache to be rebuilt") : _("Cache will not rebuild.") , __FILE__, __LINE__);
+debugMessage((!empty($useCache)) ? gTranslate('core', "Using cache") : gTranslate('core', "Not using cache") ,__FILE__, __LINE__);
+debugMessage((!empty($refreshcache)) ? gTranslate('core', "Cache to be rebuilt") : gTranslate('core', "Cache will not rebuild.") , __FILE__, __LINE__);
 
 // Check if photo data will be loaded from the caches.
 // If it isn't, then load the photos data and sort.
@@ -370,7 +370,7 @@ if (empty($useCache)) {
 	}
         $statsAlbum = $list[$i];
         if ($statsAlbum->versionOutOfDate()) {
-            debugMessage(_("Version out of date."), __FILE__, __LINE__, 2);
+            debugMessage(gTranslate('core', "Version out of date."), __FILE__, __LINE__, 2);
             $skip[] = $statsAlbum;
             continue;
         }
@@ -402,7 +402,7 @@ if (empty($useCache)) {
 
         $uid = $gallery->user->getUid();
         if ($statsAlbum->canRead($uid) || $gallery->user->isAdmin() || $statsAlbum->isOwner($uid))  {
-            debugMessage(sprintf (_("Checking album: %s"), $statsAlbum->fields['name']), __FILE__, __LINE__);
+            debugMessage(sprintf (gTranslate('core', "Checking album: %s"), $statsAlbum->fields['name']), __FILE__, __LINE__);
 
             // Haplo code to make sense of the Gallery rankings.
             /*
@@ -412,7 +412,7 @@ if (empty($useCache)) {
             */
             $numPhotos = $statsAlbum->numPhotos(1);
             for ($j = 1; $j <= $numPhotos; $j++) {
-                debugMessage(sprintf (_("Reading info for photo index = %d , id = %d"), $j, $statsAlbum->getPhotoId($j)), __FILE__, __LINE__, 2);
+                debugMessage(sprintf (gTranslate('core', "Reading info for photo index = %d , id = %d"), $j, $statsAlbum->getPhotoId($j)), __FILE__, __LINE__, 2);
 
                 if (! $statsAlbum->isAlbum($j) && (!$statsAlbum->isHidden($j) || $gallery->user->isAdmin())) {
                     $uploaddate = $statsAlbum->getUploadDate($j);
@@ -423,16 +423,16 @@ if (empty($useCache)) {
                         // otherwise display all.
                         if ($type != "comments" || ( $statsAlbum->numComments($j) > 0 && $statsAlbum->canViewComments($uid) )) {
                             if (isset($showVotes) || $type == "votes" ) {
-                                debugMessage(_("Getting SVotes"), __FILE__, __LINE__, 2);
+                                debugMessage(gTranslate('core', "Getting SVotes"), __FILE__, __LINE__, 2);
                                 $votes = $statsAlbum->getItemSVotes($j);
                             } else {
                                 $votes = '';
                             }
 
-                            debugMessage(_("Getting Item Clicks"), __FILE__, __LINE__, 2);
+                            debugMessage(gTranslate('core', "Getting Item Clicks"), __FILE__, __LINE__, 2);
                             $views = $statsAlbum->getItemClicks($j);
 
-                            debugMessage(_("Getting Item Capture Date"), __FILE__, __LINE__, 2);
+                            debugMessage(gTranslate('core', "Getting Item Capture Date"), __FILE__, __LINE__, 2);
                             $captureDate = $statsAlbum->getItemCaptureDate($j);
 
                             // If the user wants stats for a capture date of a
@@ -451,9 +451,9 @@ if (empty($useCache)) {
                             }
 
 
-                            debugMessage(_("Getting Number of Comments"), __FILE__, __LINE__, 2);
+                            debugMessage(gTranslate('core', "Getting Number of Comments"), __FILE__, __LINE__, 2);
                             if ($statsAlbum->numComments($j) > 0 )  {
-                                debugMessage(_("Getting Comments"), __FILE__, __LINE__, 2);
+                                debugMessage(gTranslate('core', "Getting Comments"), __FILE__, __LINE__, 2);
                                 $comment = $statsAlbum->getComment( $j, $statsAlbum->numComments($j) );
                                 $commentDate = $comment->datePosted;
                             }
@@ -462,7 +462,7 @@ if (empty($useCache)) {
                             }
                             /*
                             if (isset($showRatings) || $type == "ratings" ) {
-                            debugMessage(_("Getting Ratings"), __FILE__, __LINE__, 2);
+                            debugMessage(gTranslate('core', "Getting Ratings"), __FILE__, __LINE__, 2);
 
                             if (!empty($ratingAverageList[$j])) {
                             $ratingCount = $ratingAverageList[$j]['count'];
@@ -496,8 +496,8 @@ if (empty($useCache)) {
                                 "rating" => $rating,
                                 "ratingcount" => $ratingCount,
                                 "random" => $randomNum );
-                            debugMessage(sprintf (_("Album: %s ; Index: %d ; Votes: %d ; Views: %d; Date: %s; Capture: %s; Comment Date: %s; Rating: %s; Rating count: %d; Random: %d"). "<br>",
-                                $statsAlbum->fields['name'], $j, $votes, $views, $uploaddate, $captureDate, $commentDate, $rating, $ratingCount, $randomNum) 
+                            debugMessage(sprintf (gTranslate('core', "Album: %s ; Index: %d ; Votes: %d ; Views: %d; Date: %s; Capture: %s; Comment Date: %s; Rating: %s; Rating count: %d; Random: %d"). "<br>",
+                                $statsAlbum->fields['name'], $j, $votes, $views, $uploaddate, $captureDate, $commentDate, $rating, $ratingCount, $randomNum)
 				, __FILE__, __LINE__, 1);
                         }
                     }
@@ -558,7 +558,7 @@ $startPhoto = ($page - 1) * $photosPerPage;
 
 // Use fuz factor to avoid rounding up when result is 0.5
 $lastpage = round( ($totalPhotosToDisplay / $photosPerPage) - 0.500001) + 1;
-debugMessage(sprintf(_("Total: %s ; Start: %s ; Last Page: %s"), $totalPhotosToDisplay, $startPhoto, $lastpage), __FILE__, __LINE__);
+debugMessage(sprintf(gTranslate('core', "Total: %s ; Start: %s ; Last Page: %s"), $totalPhotosToDisplay, $startPhoto, $lastpage), __FILE__, __LINE__);
 
 $borderColor = $gallery->app->default["bordercolor"];
 if (isset($tsz) ) {
@@ -579,28 +579,28 @@ $adminText = "";
 if (isset($album)) {
     if (isset($albumobj)) {
         if ($type == "comments" ) {
-            $adminText .= sprintf(_("%d images with comments in album: %s"), count($arrPhotos), $albumLink);
+            $adminText .= sprintf(gTranslate('core', "%d items with comments in album: %s."), count($arrPhotos), $albumLink);
         } else {
-            $adminText .= sprintf(_("%d images in album: %s"), count($arrPhotos), $albumLink);
+            $adminText .= sprintf(gTranslate('core', "%d items in album: %s"), count($arrPhotos), $albumLink);
         }
     } else {
-        $adminText .= sprintf(_("Given albumname: '%s' is invalid !"), $album);
+        $adminText .= sprintf(gTranslate('core', "Given albumname: '%s' is invalid!"), $album);
     }
 }
 else {
     if ($type == "comments" ) {
-        $adminText .= sprintf(_("%d images with comments in this Gallery"), count($arrPhotos));
+        $adminText .= sprintf(gTranslate('core', "%d items with comments in this Gallery."), count($arrPhotos));
     }
     else {
-        $adminText .= sprintf(_("%d images this Gallery"), count($arrPhotos));
+        $adminText .= sprintf(gTranslate('core', "%d items this Gallery."), count($arrPhotos));
     }
 }
 
 $adminbox["commands"] = '';
 if ($gallery->user->isAdmin()) {
-    $adminbox["commands"] = '[<a href="'. makeGalleryURL('stats-wizard.php') .'">'. _("Back to stats-wizard") .'</a>] ';
+    $adminbox["commands"] = '[<a href="'. makeGalleryURL('stats-wizard.php') .'">'. gTranslate('core', "Back to stats-wizard") .'</a>] ';
 }
-$adminbox["commands"] .= '[<a href="'. makeAlbumUrl() .'">'. _("return to gallery") .'</a>]';
+$adminbox["commands"] .= '[<a href="'. makeAlbumUrl() .'">'. gTranslate('core', "Return to gallery") .'</a>]';
 
 
 if (!empty($gallery->app->stats_foruser)) {
@@ -634,7 +634,7 @@ if ($useCache ) {
 }
 if (isset($stm)) {
     $time = getmicrotime() - $time_start;
-    echo sprintf(_("Data load time %d seconds"), $time);
+    echo sprintf(gTranslate('core', "Data load time %d seconds."), $time);
 }
 
 /* Start of album layout style. */
@@ -700,20 +700,20 @@ for ($j = $startPhoto; $j < $totalPhotosToDisplay && $j < $startPhoto + $photosP
 echo $statsTable->render();
 
 $time = getmicrotime() - $time_start;
-echo infoLine(sprintf (_("Finished in %d seconds"), $time), 'success1');
+echo infoLine(sprintf (gTranslate('core', "Finished in %d seconds"), $time), 'success1');
 
 if ($cacheReloadRequired) {
     $url = makeStatsUrl( $page );
     $url .= "&refreshcache=1";
-    $urlhref = '<a href="'. $url .'">['. _("Update") .']</a>';
-    echo gallery_error(_("Cache update required. ").$urlhref);
+    $urlhref = '<a href="'. $url .'">['. gTranslate('core', "Update") .']</a>';
+    echo gallery_error(gTranslate('core', "Cache update required. ").$urlhref);
 }
 
 if (sizeof($skip) > 0) {
-    echo gallery_error(sprintf(_("Some albums not searched as they require upgrading to the latest version of %s first"),Gallery()));
+    echo gallery_error(sprintf(gTranslate('core', "Some albums not searched as they require upgrading to the latest version of %s first"),Gallery()));
     if ($gallery->user->isAdmin()) {
         print ":<br>";
-        echo popup_link(_("upgrade all albums"), "upgrade_album.php");
+        echo popup_link(gTranslate('core', "upgrade all albums"), "upgrade_album.php");
         print "<br>(";
         $join_text='';
         foreach($skip as $stalbum) {
@@ -757,7 +757,7 @@ function getmicrotime() {
 function recurseAlbums( $parentAlbum) {
     global $list, $gallery;
     if ($parentAlbum) {
-        debugMessage(sprintf(_("Recursing album: %s"),  $parentAlbum->fields['name']),__FILE__, __LINE__, 2);
+        debugMessage(sprintf(gTranslate('core', "Recursing album: %s"),  $parentAlbum->fields['name']),__FILE__, __LINE__, 2);
 
         $numPhotos = $parentAlbum->numPhotos(1);
         for ($j = 1; $j <= $numPhotos; $j++) {
@@ -793,7 +793,7 @@ function readCacheNumPhotos( $cacheFilename ) {
             myFlock($fd, LOCK_UN);
         }
         else {
-            debugMessage(_("Read cache num photos lock failed."), __FILE__, __LINE__, 2);
+            debugMessage(gTranslate('core', "Read cache num photos lock failed."), __FILE__, __LINE__, 2);
         }
         fclose($fd);
     }
@@ -817,7 +817,7 @@ function readGalleryStatsCache( $cacheFilename, $start, $numPhotos ) {
             for ( $i = 0; $i < $numPhotos; ++$i ) {
                 $data = fgetcsv($fd,$size,'|');
                 if ($data ) {
-                    debugMessage(sprintf(_("Album name : %s ; index: %s"), $data[0], $data[1]), __FILE__, __LINE__, 1);
+                    debugMessage(sprintf(gTranslate('core', "Album name: %s ; Index: %s"), $data[0], $data[1]), __FILE__, __LINE__, 1);
 
                     $arrPhotos[$start+$i] = array("albumName" => $data[0],
 			'photoId' => $data[1],
@@ -828,7 +828,7 @@ function readGalleryStatsCache( $cacheFilename, $start, $numPhotos ) {
             myFlock($fd, LOCK_UN);
         }
         else {
-            debugMessage(_("Read cache lock failed."), __FILE__, __LINE__, 2);
+            debugMessage(gTranslate('core', "Read cache lock failed."), __FILE__, __LINE__, 2);
         }
         fclose($fd);
     }
@@ -867,7 +867,7 @@ function writeGalleryStatsCache( $cacheFilename ) {
             myFlock($fd, LOCK_UN);
         }
         else {
-            debugMessage(_("Read cache lock failed."), __FILE__, __LINE__, 2);
+            debugMessage(gTranslate('core', "Read cache lock failed."), __FILE__, __LINE__, 2);
         }
         fclose($fd);
     }
@@ -966,7 +966,7 @@ function showAddCommentLink( $photoId ) {
     global $statsAlbum;
 
     $url = "add_comment.php?set_albumName={$statsAlbum->fields['name']}&id=$photoId";
-    return '<span class="fineprint">' . popup_link('[' . _("add comment") . ']', $url, 0) . "</span>";
+    return '<span class="fineprint">' . popup_link('[' . gTranslate('core', "add comment") . ']', $url, 0) . "</span>";
 }
 
 // Show the add vote link
@@ -979,7 +979,7 @@ function showAddVoteLink( $photoId, $page ) {
 
     $addVoteLink = '<span class="fineprint">';
     $addVoteLink .= '<a href="'. makeGalleryUrl("vote.php", $urlargs) . '">';
-    $addVoteLink .= "[". _("add vote") ."]";
+    $addVoteLink .= "[". gTranslate('core', "add vote") ."]";
     $addVoteLink .= "</a></span>";
 
     return $addVoteLink;
@@ -1073,12 +1073,12 @@ function displayTextCell($statsAlbum, $photoIndex, $photoId, $rating, $ratingcou
     // End Caption
 
     if ($showAlbumLink ) {
-        $albumLink = sprintf(_("From album: %s"),
+        $albumLink = sprintf(gTranslate('core', "From album: %s"),
           '<a href="'. makeAlbumUrl($statsAlbum->fields['name']) .'">'. $statsAlbum->fields['title'] . '</a>');
 
         $owner_var = '';
         if ($showAlbumOwner == 1 ) {
-            $owner_var = '<br>' . sprintf(_("Owned by: %s"), showOwner($statsAlbum->getOwner()));
+            $owner_var = '<br>' . sprintf(gTranslate('core', "Owned by: %s"), showOwner($statsAlbum->getOwner()));
         }
 
         $html .= "\n    " . '<div class="fineprint">'. $albumLink . $owner_var . '</div>';
@@ -1110,7 +1110,7 @@ function displayTextCell($statsAlbum, $photoIndex, $photoId, $rating, $ratingcou
         $captureDate = strftime($gallery->app->dateTimeString, $statsAlbum->getItemCaptureDate($photoIndex));
 
         $innerStatsTable->addElement(array(
-            'content' => _("Capture Date:"),
+            'content' => gTranslate('core', "Capture Date:"),
             'cellArgs' => array('width' => 100)));
 
         $innerStatsTable->addElement(array(
@@ -1124,7 +1124,7 @@ function displayTextCell($statsAlbum, $photoIndex, $photoId, $rating, $ratingcou
         if ($time) {
             $time = strftime($gallery->app->dateString,$time);
             $innerStatsTable->addElement(array(
-                'content' => _("Upload Date:"),
+                'content' => gTranslate('core', "Upload Date:"),
                 'cellArgs' => array('width' => 100)));
 
             $innerStatsTable->addElement(array(
@@ -1138,17 +1138,17 @@ function displayTextCell($statsAlbum, $photoIndex, $photoId, $rating, $ratingcou
        !$gallery->session->offline) {
 
         $innerStatsTable->addElement(array(
-            'content' => _("Viewed:"),
+            'content' => gTranslate('core', "Viewed:"),
             'cellArgs' => array('width' => 100)));
 
         $innerStatsTable->addElement(array(
-            'content' => gTranslate('core', "Once", "%d times" , $statsAlbum->getItemClicks($photoIndex), _("Never viewed")),
+            'content' => gTranslate('core', "Once", "%d times" , $statsAlbum->getItemClicks($photoIndex), gTranslate('core', "Never viewed")),
             'cellArgs' => array('class' => 'fineprint')));
     }
 
     if (!empty($showVotes )) {
         $innerStatsTable->addElement(array(
-            'content' => _("Votes:"),
+            'content' => gTranslate('core', "Votes:"),
             'cellArgs' => array('width' => 100)));
 
         $innerStatsTable->addElement(array(
@@ -1160,7 +1160,7 @@ function displayTextCell($statsAlbum, $photoIndex, $photoId, $rating, $ratingcou
         switch ($rating) {
             case -2:
                 $photoRateCounts = '';
-                $photoRate = _("not rated");
+                $photoRate = gTranslate('core', "not rated");
                 break;
             case -1:
                 $photoRateCounts = '';
@@ -1174,7 +1174,7 @@ function displayTextCell($statsAlbum, $photoIndex, $photoId, $rating, $ratingcou
         }
 
         $innerStatsTable->addElement(array(
-            'content' => _("Rating:"),
+            'content' => gTranslate('core', "Rating:"),
             'cellArgs' => array('width' => 100)));
 
         $innerStatsTable->addElement(array(
