@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2006 Bharat Mediratta
+ * Copyright (C) 2000-2007 Bharat Mediratta
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: util.php 14311 2006-08-14 07:49:09Z jenst $
+ * $Id: util.php 16862 2007-08-12 14:13:11Z jenst $
  */
 
 /**
@@ -42,12 +42,12 @@ function getRequestVar($str) {
             return null;
         }
         $ret = & $_REQUEST[$str];
+
+        if (get_magic_quotes_gpc()) {
+            $ret = stripslashes_deep($ret);
+        }
         //echo "\n<br>- Checking:". htmlspecialchars($str);
         $ret = sanitizeInput($ret);
-
-        if (get_magic_quotes_gpc() && !is_array($ret)) {
-            $ret = stripslashes($ret);
-        }
     }
     else {
         foreach ($str as $reqvar) {
@@ -208,7 +208,7 @@ function getDimensions($file) {
     debugMessage(sprintf(gTranslate('core', "Getting Dimension of file: %s"), $file), __FILE__, __LINE__, 2);
 
     if (! fs_file_exists($file)) {
-        debugMessage(gTranslate('core', "The file does not exist ?!"), __FILE__, __LINE__);
+        debugMessage(gTranslate('core', "The file does not exist?!"), __FILE__, __LINE__);
         return array(0, 0);
     }
 
@@ -224,9 +224,9 @@ function getDimensions($file) {
 
     /* Just in case php can't determine dimensions. */
     switch($gallery->app->graphics) {
-        case 'NetPBM':
+        case 'Netpbm':
             list($lines, $status) = exec_internal(toPnmCmd($file) ." | ".
-                NetPBM('pnmfile', '--allimages'));
+                Netpbm('pnmfile', '--allimages'));
             break;
         case "ImageMagick":
             /* This fails under windows, IM isn't returning parsable status output. */
@@ -242,7 +242,7 @@ function getDimensions($file) {
     if ($status == $gallery->app->expectedExecStatus) {
         foreach ($lines as $line) {
             switch($gallery->app->graphics) {
-                case 'NetPBM':
+                case 'Netpbm':
                     if (ereg("([0-9]+) by ([0-9]+)", $line, $regs)) {
                         return array($regs[1], $regs[2]);
                     }
@@ -603,7 +603,10 @@ function getExif($file) {
                 $explodeReturn = explode(':', $value, 2);
                 $exifDesc = trim(htmlentities($explodeReturn[0]));
                 $exifData = trim(htmlentities($explodeReturn[1]));
-                if(!empty($exifData) && !in_array($exifDesc, $unwantedFields)) {
+                if(!empty($exifData) &&
+                   !in_array($exifDesc, $unwantedFields) &&
+                   !isset($myExif[$exifDesc]))
+                {
                     if (isset($myExif[$exifDesc])) {
                         $myExif[$exifDesc] .= "<br>";
                     } else {
@@ -625,6 +628,8 @@ function getExif($file) {
  * Note: i used switch/case because this is easier to extend later.
  */
 function getItemCaptureDate($file) {
+	global $gallery;
+
 	$success = false;
 	$exifSupported = getExifDisplayTool();
 
@@ -632,17 +637,17 @@ function getItemCaptureDate($file) {
 		$return = getExif($file);
 		$exifData = $return[1];
 		switch($exifSupported) {
-                	case 'exiftags':
+			case 'exiftags':
 				if (isset($exifData['Image Created'])) {
 					$tempDate = split(" ", $exifData['Image Created'], 2);
 				}
-                        	break;
-	                case 'jhead':
+				break;
+			case 'jhead':
 				if (isset($exifData['Date/Time'])) {
 					$tempDate = split(" ", $exifData['Date/Time'], 2);
 				}
-        	                break;
-        	}
+				break;
+		}
 		if (isset($tempDate)) {
 			$tempDay = strtr($tempDate[0], ':', '-');
 			$tempTime = $tempDate[1];
@@ -658,11 +663,13 @@ function getItemCaptureDate($file) {
 	// we were not able to get the capture date from exif... use file creation time
 	if (!$success) {
 		$itemCaptureTimeStamp = filemtime($file);
+		echo debugMessage(gTranslate('core', "Got no capture date. Using file modification time."),
+						  __FILE__, __LINE__);
 	}
 
-	if (!isDebugging()) {
-		sprintf (gTranslate('core', "Item Capture Date : %s"), strftime('%Y', $itemCaptureTimeStamp));
-	}
+	echo debugMessage(sprintf (gTranslate('core', "Item Capture Date: %s"),
+							strftime($gallery->app->dateTimeString, $itemCaptureTimeStamp)),
+					  __FILE__, __LINE__);
 
 	return $itemCaptureTimeStamp;
 }
@@ -1205,7 +1212,33 @@ function getImVersion() {
     global $gallery;
     $version = array();
 
-    exec($gallery->app->ImPath .'/convert -version', $results);
+    fs_exec($gallery->app->ImPath .'/convert -version', $results, $status);
+
+    $pieces = explode(' ', $results[0]);
+    $version = $pieces[2];
+
+    return $version;
+}
+
+/**
+ * Return the version number of jhead, identified by "jhead -v"
+ * @return $version	string	Versionnumber as string
+*/
+function getJheadVersion($dir = '') {
+    global $gallery;
+    
+	$bin = fs_executable('jhead');
+
+    if(empty($dir)) {
+		$dir = locateDir($bin, isset($gallery->app->use_exif) ? dirname($gallery->app->use_exif) : "");
+		if(empty($dir)) {
+			return 0;
+		}
+	}
+
+	$path ="$dir/$bin";
+
+    fs_exec($path . ' -V', $results, $status);
 
     $pieces = explode(' ', $results[0]);
     $version = $pieces[2];
@@ -1365,6 +1398,10 @@ function testRequirement($test) {
             $result = isset($gallery->app->watermarkDir);
         break;
 
+        case 'exif':
+        	$result = (getExifDisplayTool() !== false);
+        break;
+
         default:
             $result = false;
         break;
@@ -1682,12 +1719,12 @@ function parse_ecard_template($ecard,$ecard_data, $preview = true) {
     $imagePath = $gallery->album->getAbsolutePhotoPath($ecard['photoIndex'], false);
     $photo = $gallery->album->getPhoto($ecard['photoIndex']);
     if($preview) {
-	$imageName = $gallery->album->getPhotoPath($ecard['photoIndex'], false);
-	$stampName = getImagePath('ecard_images/'. $ecard['stamp'] .'.gif');
+        $imageName = $gallery->album->getPhotoPath($ecard['photoIndex'], false);
+        $stampName = getImagePath('ecard_images/'. $ecard['stamp'] .'.gif');
     }
     else {
-	$imageName = $photo->getImageName(false);
-	$stampName = $ecard['stamp'] .'.gif';
+        $imageName = $photo->getImageName(false);
+        $stampName = $ecard['stamp'] .'.gif';
     }
 
     list ($width, $height) = getDimensions($imagePath);
@@ -1697,13 +1734,13 @@ function parse_ecard_template($ecard,$ecard_data, $preview = true) {
     $ecard_data = preg_replace ("/<%ecard_sender_name%>/", $ecard["name_sender"], $ecard_data);
     $ecard_data = preg_replace ("/<%ecard_image_name%>/", $imageName, $ecard_data);
     $ecard_data = preg_replace ("/<%ecard_message%>/", preg_replace ("/\r?\n/", "<BR>\n", htmlspecialchars($ecard["message"])), $ecard_data);
-    $ecard_data = preg_replace ("/<%ecard_reciepient_email%>/", $ecard["email_recepient"], $ecard_data);
-    $ecard_data = preg_replace ("/<%ecard_reciepient_name%>/", $ecard["name_recepient"], $ecard_data);
+    $ecard_data = preg_replace ("/<%ecard_reciepient_email%>/", $ecard["email_recipient"], $ecard_data);
+    $ecard_data = preg_replace ("/<%ecard_reciepient_name%>/", $ecard["name_recipient"], $ecard_data);
     $ecard_data = preg_replace ("/<%ecard_stamp%>/", $stampName, $ecard_data);
     $ecard_data = preg_replace ("/<%ecard_width%>/", $widthReplace, $ecard_data);
 
     return $ecard_data;
-  }
+}
 
   function send_ecard($ecard,$ecard_HTML_data,$ecard_PLAIN_data) {
       global $gallery;
@@ -1743,7 +1780,7 @@ function parse_ecard_template($ecard,$ecard_data, $preview = true) {
       $ecard_mail->setSubject($ecard['subject']);
       $ecard_mail->setReturnPath($ecard["email_sender"]);
 
-      $result = $ecard_mail->send(array($ecard["name_recepient"] .' <'. $ecard["email_recepient"] .'>'));
+      $result = $ecard_mail->send(array($ecard["name_recipient"] .' <'. $ecard["email_recipient"] .'>'));
 
       return $result;
   }
@@ -1835,7 +1872,7 @@ function createTempAlbum($albumItemNames = array(), $dir = '') {
 
     if(! fs_mkdir($dir)) {
         echo gallery_error(
-          sprintf(gTranslate('core', "Gallery was unable to create a tempory subfolder in your tempdir. Please check permissions of this dir: %s"),
+          sprintf(gTranslate('core', "Gallery was unable to create a temporary subfolder in your tempdir. Please check permissions of this dir: %s"),
         $gallery->app->tmpDir));
         return false;
     }
@@ -1887,7 +1924,7 @@ function downloadFile($filename) {
         return false;
     }
     elseif ($validFileName == 0 || dirname($filename) == $gallery->app->tmpDir) {
-        echo gallery_error(gTranslate('core', "We are trying to download the tempdir itself ?! Download aborted."));
+        echo gallery_error(gTranslate('core', "We are trying to download the tempdir itself?! Download aborted."));
         return false;
     }
 
@@ -1938,6 +1975,25 @@ function array_flaten($array) {
     return $flatArray;
 }
 
+/**
+ * This function returns the Gallery Title as a string thats save to show in <title>...</title>
+ *
+ * @param string $topic	 optional
+ * @return string $ret
+ * @author Jens Tkotz
+ */
+function clearGalleryTitle($topic = '') {
+	global $gallery;
+
+	$ret = strip_tags($gallery->app->galleryTitle);
+
+	if($topic != '') {
+		$ret .= ' :: ' . $topic;
+	}
+
+	return $ret;
+}
+
 require_once(dirname(__FILE__) . '/lib/lang.php');
 require_once(dirname(__FILE__) . '/lib/Form.php');
 require_once(dirname(__FILE__) . '/lib/voting.php');
