@@ -1,7 +1,7 @@
 <?php
 /*
 * Gallery - a web based photo album viewer and editor
-* Copyright (C) 2000-2006 Bharat Mediratta
+* Copyright (C) 2000-2007 Bharat Mediratta
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 *
-* $Id: view_album.php 14311 2006-08-14 07:49:09Z jenst $
+* $Id: view_album.php 16794 2007-07-30 05:41:01Z jenst $
 */
 ?>
 <?php
@@ -27,7 +27,10 @@ require_once(dirname(__FILE__) . '/init.php');
 list($page,$votes, $Vote) = getRequestVar(array('page', 'votes', 'Vote'));
 
 // Hack check and prevent errors
-if (empty($gallery->session->albumName) || !$gallery->user->canReadAlbum($gallery->album) || !$gallery->album->isLoaded()) {
+if (empty($gallery->session->albumName) ||
+    !$gallery->user->canReadAlbum($gallery->album) ||
+    !$gallery->album->isLoaded())
+{
     $gallery->session->gRedirDone = false;
     header("Location: " . makeAlbumHeaderUrl('', '', array('gRedir' => 1)));
     return;
@@ -48,14 +51,18 @@ if (empty($page) || $page < 0) {
 
 $albumName = $gallery->session->albumName;
 
-if (!isset($gallery->session->viewedAlbum[$albumName]) && !$gallery->session->offline) {
+$noCount = getRequestVar('noCount');
+if ($noCount != 1 && !isset($gallery->session->viewedAlbum[$albumName])
+    && !$gallery->session->offline) {
     $gallery->session->viewedAlbum[$albumName] = 1;
     $gallery->album->incrementClicks();
 }
 
 $rows = $gallery->album->fields["rows"];
 $cols = $gallery->album->fields["cols"];
+
 list ($numPhotos, $numAlbums, $visibleItems) = $gallery->album->numVisibleItems($gallery->user, 1);
+
 $numVisibleItems = $numPhotos + $numAlbums;
 $perPage = $rows * $cols;
 $maxPages = max(ceil(($numPhotos + $numAlbums) / $perPage), 1);
@@ -79,7 +86,7 @@ if ($previousPage == 0) {
     $first = 1;
 }
 
-if (!empty($Vote)) {
+if (!empty($Vote) && canVote()) {
     if ($gallery->album->getPollScale() == 1 && $gallery->album->getPollType() != "rank") {
         for ($index=$start; $index < $start+$perPage; $index ++) {
             $id=$gallery->album->getPhotoId($index);
@@ -105,9 +112,8 @@ $navigator["spread"] = 5;
 $navigator["bordercolor"] = $bordercolor;
 
 $fullWidth = $navigator["fullWidth"] . $navigator["widthUnits"];
-$upArrowURL = '<img src="' . getImagePath('nav_home.gif') . '" width="13" height="11" ' .
-  'alt="' . gTranslate('core', "navigate UP") .'" title="' . gTranslate('core', "navigate UP") .'" border="0">';
 
+$upArrowURL = gImage('nav_home.gif', gTranslate('core', "navigate UP"));
 if ($gallery->album->fields['returnto'] != 'no') {
     foreach ($gallery->album->getParentAlbums() as $navAlbum) {
         $breadcrumb["text"][] = $navAlbum['prefixText'] .': <a class="bread" href="'. $navAlbum['url'] . '">'.
@@ -119,28 +125,44 @@ $breadcrumb["bordercolor"] = $bordercolor;
 
 global $GALLERY_EMBEDDED_INSIDE;
 if (!$GALLERY_EMBEDDED_INSIDE) {
+    $title = sprintf(
+        htmlspecialchars($gallery->app->galleryTitle) .
+        " :: " .
+        htmlspecialchars($gallery->album->fields["title"])
+    );
+
     doctype();
 ?>
 <html>
 <head>
-  <title><?php echo $gallery->app->galleryTitle ?> :: <?php echo $gallery->album->fields["title"] ?></title>
+  <title><?php echo $title ?></title>
   <?php common_header();
   /* RSS */
   if ($gallery->app->rssEnabled == "yes" && !$gallery->session->offline) {
-  	$title = sprintf(gTranslate('core', "%s RSS"), $gallery->app->galleryTitle . " :: " . $gallery->album->fields["title"]);
+  	$rssTitle = sprintf(gTranslate('core', "%s RSS"), $title);
 	$rssHref = $gallery->app->photoAlbumURL . "/rss.php?set_albumName=" . $gallery->album->fields["name"];
-  	?>
-  <link rel="alternate" title="<?php echo $title; ?>" href="<?php echo $rssHref; ?>" type="application/rss+xml">
-  <?php
+
+	echo "<link rel=\"alternate\" title=\"$rssTitle\" href=\"$rssHref\" type=\"application/rss+xml\">";
   }
   /* prefetching/navigation */
+    $firstUrl  = makeAlbumUrl($gallery->session->albumName, '',
+                    array('page' => 1, 'noCount' => 1));
+	$prevUrl   = makeAlbumUrl($gallery->session->albumName, '',
+	               array('page' => $previousPage, 'noCount' => 1));
+	$nextUrl   = makeAlbumUrl($gallery->session->albumName, '',
+	               array('page' => $nextPage, 'noCount' => 1));
+	$lastUrl   = makeAlbumUrl($gallery->session->albumName, '',
+	               array('page' => $maxPages, 'noCount' => 1));
+	$upUrl     = makeAlbumUrl($gallery->album->fields['parentAlbumName'], '',
+	               array('page' => $maxPages, 'noCount' => 1));
+
   if (!isset($first)) { ?>
-  <link rel="first" href="<?php echo makeAlbumUrl($gallery->session->albumName, '', array('page' => 1)) ?>" >
-  <link rel="prev" href="<?php echo makeAlbumUrl($gallery->session->albumName, '', array('page' => $previousPage)) ?>" >
+  <link rel="first" href="<?php echo $firstUrl; ?>" >
+  <link rel="prev" href="<?php echo $prevUrl; ?>" >
 <?php }
   if (!isset($last)) { ?>
-  <link rel="next" href="<?php echo makeAlbumUrl($gallery->session->albumName, '', array('page' => $nextPage)) ?>" >
-  <link rel="last" href="<?php echo makeAlbumUrl($gallery->session->albumName, '', array('page' => $maxPages)) ?>" >
+  <link rel="next" href="<?php echo $nextUrl; ?>" >
+  <link rel="last" href="<?php echo $lastUrl; ?>" >
 <?php } if ($gallery->album->isRoot() &&
 (!$gallery->session->offline ||
 	 isset($gallery->session->offlineAlbums["albums.php"]))) { ?>
@@ -148,7 +170,7 @@ if (!$GALLERY_EMBEDDED_INSIDE) {
 <?php
 	 } else if (!$gallery->session->offline ||
 	 isset($gallery->session->offlineAlbums[$pAlbum->fields['parentAlbumName']])) { ?>
-  <link rel="up" href="<?php echo makeAlbumUrl($gallery->album->fields['parentAlbumName']); ?>" >
+  <link rel="up" href="<?php echo $upUrl; ?>" >
 <?php }
 if (!$gallery->session->offline ||
 	 isset($gallery->session->offlineAlbums["albums.php"])) { ?>
@@ -300,6 +322,12 @@ $adminOptions = array(
         'action' => 'popup',
         'value' => doCommand('remake-thumbnail',
             array('set_albumName' => $gallery->session->albumName, 'index' => 'all', 'type' => 'popup'))),
+    'rebuild_capture_dates' => array(
+		'name'          => gTranslate('core', "Rebuild capture dates"),
+		'requirements'  => array('canWriteToAlbum', 'photosExist', 'exif'),
+		'action'        => 'popup',
+		'value'         => makeGalleryUrl('rebuild_capture_dates.php',
+							array('set_albumName' => $gallery->session->albumName,'type' => 'popup'))),
     'properties'      => array(
         'name' => gTranslate('core', "Properties"),
         'requirements' => array('canWriteToAlbum'),
@@ -373,6 +401,9 @@ if (!$gallery->session->offline) {
 
 $adminCommands = '';
 $adminJSFrame = '';
+
+$iconElements = array();
+
 /* build up drop-down menu and related javascript */
 if (!empty($adminOptionHTML)) {
     $adminJSFrame .= "<script language=\"javascript1.2\" type=\"text/JavaScript\">\n"
@@ -402,7 +433,7 @@ if (!empty($adminOptionHTML)) {
 
 if ($gallery->album->fields["slideshow_type"] != "off" &&
 ($numPhotos != 0 || ($numVisibleItems != 0 && $gallery->album->fields['slideshow_recursive'] == "yes"))) {
-    $iconText = getIconText('display.gif', gTranslate('core', "slideshow"));
+    $iconText = getIconText('display.gif', gTranslate('core', "Slideshow"));
     $iconElements[] = '<a href="'
     . makeGalleryUrl("slideshow.php",
     array("set_albumName" => $albumName)) .'">'. $iconText .'</a>';
@@ -412,7 +443,7 @@ if ($gallery->album->fields["slideshow_type"] != "off" &&
 if ( $numVisibleItems != 0 && ($gallery->app->comments_enabled == 'yes' && $gallery->album->lastCommentDate("no") != -1) &&
 ((isset($gallery->app->comments_overview_for_all) && $gallery->app->comments_overview_for_all == "yes") ||
 $gallery->user->canViewComments($gallery->album))) {
-    $iconText = getIconText('showcomment.gif', gTranslate('core', "view&nbsp;comments"));
+    $iconText = getIconText('showcomment.gif', gTranslate('core', "View&nbsp;comments"));
     $iconElements[] = '<a href="'.
     makeGalleryUrl("view_comments.php",
     array("set_albumName" => $gallery->session->albumName)) . '">'. $iconText .'</a>';
@@ -420,12 +451,12 @@ $gallery->user->canViewComments($gallery->album))) {
 
 if (!$GALLERY_EMBEDDED_INSIDE && !$gallery->session->offline) {
     if ($gallery->user->isLoggedIn()) {
-        $iconText = getIconText('exit.gif', gTranslate('core', "logout"));
+        $iconText = getIconText('exit.gif', gTranslate('core', "Logout"));
         $iconElements[] = '<a href="'.
         doCommand("logout", array(), "view_album.php",
         array("page" => $page, 'set_albumName' => $albumName)) .'">'. $iconText .'</a>';
     } else {
-        $iconText = getIconText('identity.gif', gTranslate('core', "login"));
+        $iconText = getIconText('identity.gif', gTranslate('core', "Login"));
         $iconElements[] = popup_link($iconText, "login.php", false, true, 500, 500);
     }
 }
@@ -488,7 +519,7 @@ if (($gallery->album->getPollType() == "rank") && canVote()) {
         ksort($my_choices);
         $nv_pairs = $gallery->album->getVoteNVPairs();
 
-        $va_poll_box1 = gTranslate('core', "Your votes are :");
+        $va_poll_box1 = gTranslate('core', "Your votes are:");
 
         $pollInfoTable = new galleryTable();
         foreach ($my_choices as $key => $id) {
@@ -629,8 +660,6 @@ if ($numPhotos) {
             $visibleItemIndex++;
             $i = $visibleItemIndex <= $numVisibleItems ? $visibleItems[$visibleItemIndex] : $numPhotos+1;
         }
-        if ($printTableRow) {
-        }
 
         /* Do the picture row */
         $visibleItemIndex = $rowStart;
@@ -811,8 +840,10 @@ if ($numPhotos) {
             	echo '<div class="fineprint" style="margin-top:3px">';
             	printf (gTranslate('core', "Last change: %s"), $myAlbum->getLastModificationDate());
             	echo "\n<br>";
+
             	$visItems = array_sum($myAlbum->numVisibleItems($gallery->user));
-            	printf (gTranslate('core', "Contains: %s"), gTranslate('core', "1 item", "%d items", $visItems)) . '. ';
+            	printf(gTranslate('core', "Contains: %s."), gTranslate('core', "1 item", "%d items", $visItems));
+
             	// If comments indication for either albums or both
             	switch ($gallery->app->comments_indication) {
             		case "albums":
@@ -893,21 +924,19 @@ if ($numPhotos) {
         $visibleItemIndex = $rowStart;
         $i = $visibleItemIndex <= $numVisibleItems ? $visibleItems[$visibleItemIndex] : $numPhotos+1;
         $j = 1;
-        if ($printTableRow) {
-        }
+
         while ($j <= $cols && $i <= $numPhotos) {
             $j++;
             $visibleItemIndex++;
             $i = $visibleItemIndex<=$numVisibleItems ? $visibleItems[$visibleItemIndex] : $numPhotos+1;
         }
-        if ($printTableRow) {
-        }
+
         $rowCount++;
         $rowStart = $visibleItemIndex;
     }
 } else {
 ?>
-
+  <tr>
 	<td colspan="<?php echo $rows ?>" align="center" class="headbox">
 <?php if ($gallery->user->canAddToAlbum($gallery->album) && !$gallery->session->offline) {
     $url = makeGalleryUrl('add_photos_frame.php', array('set_albumName' => $gallery->session->albumName, 'type' => 'popup'));
@@ -938,40 +967,53 @@ if (canVote()) { ?>
 <?php
 }
 
-?>
-	</form>
-<?php if ($gallery->user->isLoggedIn() &&
-$gallery->user->getEmail() &&
-!$gallery->session->offline &&
-$gallery->app->emailOn == "yes") {
+echo "\n</form>";
+
+if ($gallery->user->isLoggedIn() &&
+	$gallery->user->getEmail() &&
+	!$gallery->session->offline &&
+	$gallery->app->emailOn == "yes")
+{
     if (getRequestVar('submitEmailMe')) {
         if (getRequestVar('comments')) {
-            $gallery->album->setEmailMe('comments', $gallery->user);
-        } else {
-            $gallery->album->unsetEmailMe('comments', $gallery->user);
+            $gallery->album->setEmailMe('comments', $gallery->user, null, getRequestVar('recursive'));
         }
+        else {
+            $gallery->album->unsetEmailMe('comments', $gallery->user, null, getRequestVar('recursive'));
+        }
+
         if (getRequestVar('other')) {
-            $gallery->album->setEmailMe('other', $gallery->user);
-        } else {
-            $gallery->album->unsetEmailMe('other', $gallery->user);
+            $gallery->album->setEmailMe('other', $gallery->user, null, getRequestVar('recursive'));
+        }
+        else {
+            $gallery->album->unsetEmailMe('other', $gallery->user, null, getRequestVar('recursive'));
         }
     }
+?>
+	<fieldset class="admin" style="width: 400px; margin-bottom: 2px">
+	<legend>
+    <?php echo gTranslate('core', "Email me when one of the following actions are done to this album:")."  "; ?>
+    </legend>
+<?php
     echo makeFormIntro("view_album.php",
         array("name" => "email_me", "style" => "margin-bottom: 0px;"));
-    echo gTranslate('core', "Email me when one of the following actions are done to this album:")."  ";
+
     $checked_com = ($gallery->album->getEmailMe('comments', $gallery->user)) ? "checked" : "" ;
     $checked_other = ($gallery->album->getEmailMe('other', $gallery->user)) ? "checked" : "";
-	?>
-	<ul>
-	<li><?php echo gTranslate('core', "Comments are added"); ?>
-		<input type="checkbox" name="comments" <?php echo $checked_com; ?> onclick="document.email_me.submit()">
-	</li>
-	<li><?php print gTranslate('core', "Other changes are made") ?>
-		<input type="checkbox" name="other" <?php echo $checked_other; ?> onclick="document.email_me.submit()">
-	</li>
-	</ul>
+?>
+	<input type="checkbox" name="comments" <?php echo $checked_com; ?> onclick="document.email_me.submit()">
+	<?php echo gTranslate('core', "Comments are added"); ?>
+	<br>
+	<input type="checkbox" name="other" <?php echo $checked_other; ?> onclick="document.email_me.submit()">
+	<?php print gTranslate('core', "Other changes are made") ?>
+	<hr>
+	<input type="checkbox" name="recursive" onclick="document.email_me.submit()">
+	<?php echo gTranslate('core', "Apply settings (both) recursive for subalbums."); ?>
+
 	<input type="hidden" name="submitEmailMe" value="true">
 	</form>
+	</fieldset>
+
 <?php } ?>
 <!-- bottom nav -->
 <?php
