@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2006 Bharat Mediratta
+ * Copyright (C) 2000-2007 Bharat Mediratta
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: view_photo.php 14311 2006-08-14 07:49:09Z jenst $
+ * $Id: view_photo.php 16794 2007-07-30 05:41:01Z jenst $
  */
 ?>
 <?php
@@ -74,7 +74,7 @@ if (!isset($full) || (isset($full) && !$gallery->album->isResized($index))) {
     $full = NULL;
 }
 
-if (!empty($votes)) {
+if (!empty($votes) && canVote()) {
     if (!isset($votes[$id]) &&
         $gallery->album->getPollScale() == 1 &&
         $gallery->album->getPollType() == "critique") {
@@ -89,7 +89,9 @@ if (!empty($votes)) {
 }
 
 $albumName = $gallery->session->albumName;
-if (!isset($gallery->session->viewedItem[$gallery->session->albumName][$id]) &&
+$noCount = getRequestVar('noCount');
+
+if ($noCount != 1 && !isset($gallery->session->viewedItem[$gallery->session->albumName][$id]) &&
   !$gallery->session->offline) {
     $gallery->session->viewedItem[$albumName][$id] = 1;
     $gallery->album->incrementItemClicks($index);
@@ -108,7 +110,7 @@ list($imageWidth, $imageHeight) = $image->getRawDimensions();
 
 $do_fullOnly = isset($gallery->session->fullOnly) &&
     !strcmp($gallery->session->fullOnly,"on") &&
-    strcmp($gallery->album->fields["use_fullOnly"],"yes");
+    !strcmp($gallery->album->fields["use_fullOnly"],"yes");
 
 if ($do_fullOnly) {
     $full = $gallery->user->canViewFullImages($gallery->album);
@@ -188,7 +190,7 @@ if (isset($gallery->app->comments_length)) {
     $maxlength = 0;
 }
 
-if (!empty($save)) {
+if (!empty($save) && $gallery->user->canAddComments($gallery->album)) {
     if ( empty($commenter_name) || empty($comment_text)) {
         $error_text = gTranslate('core', "Name and comment are both required to save a new comment!");
     } elseif ($maxlength >0 && strlen($comment_text) > $maxlength) {
@@ -205,6 +207,8 @@ if (!empty($save)) {
     }
 }
 
+$allImageAreas = $gallery->album->getAllImageAreas($index);
+
 $metaTags = array();
 $keyWords = $gallery->album->getKeywords($index);
 if (!empty($keyWords)) {
@@ -222,31 +226,48 @@ if (!$GALLERY_EMBEDDED_INSIDE) {
   /* prefetch/navigation */
   $navcount = sizeof($navigator['allIds']);
   $navpage = $navcount - 1;
+
+  $firstUrl  = makeAlbumUrl($gallery->session->albumName, $navigator['allIds'][0],
+                            array('noCount' => 1));
+
+  $lastUrl   = makeAlbumUrl($gallery->session->albumName, $navigator['allIds'][$navcount - 1],
+                            array('noCount' => 1));
+  $upUrl     = makeAlbumUrl($gallery->session->albumName, '', array('noCount' => 1));
+
   while ($navpage > 0) {
       if (!strcmp($navigator['allIds'][$navpage], $id)) {
           break;
       }
       $navpage--;
   }
+
   if ($navigator['allIds'][0] != $id) {
       if ($navigator['allIds'][0] != 'unknown') {
-          echo "\n  ". '<link rel="first" href="'. makeAlbumUrl($gallery->session->albumName, $navigator['allIds'][0]) .'">';
+          echo "\n  ". '<link rel="first" href="'. $firstUrl .'">';
       }
 
       if ($navigator['allIds'][$navpage-1] != 'unknown') {
-          echo "\n  ". '<link rel="prev" href="'. makeAlbumUrl($gallery->session->albumName, $navigator['allIds'][$navpage-1]) .'">';
-      }
-  }
-  if ($navigator['allIds'][$navcount - 1] != $id) {
-      if ($navigator['allIds'][$navpage+1] != 'unknown') {
-          echo "\n  ". '<link rel="next" href="'. makeAlbumUrl($gallery->session->albumName, $navigator['allIds'][$navpage+1]) .'">';
-      }
-      if ($navigator['allIds'][$navcount-1] != 'unknown') {
-          echo "\n  ". '<link rel="last" href="'. makeAlbumUrl($gallery->session->albumName, $navigator['allIds'][$navcount - 1]) .'">';
+          $prevUrl   = makeAlbumUrl($gallery->session->albumName, $navigator['allIds'][$navpage-1],
+                            array('noCount' => 1));
+
+          echo "\n  ". '<link rel="prev" href="'. $prevUrl .'">';
       }
   }
 
-  echo "\n  ". '<link rel="up" href="' . makeAlbumUrl($gallery->session->albumName) .'">';
+  if ($navigator['allIds'][$navcount - 1] != $id) {
+      if ($navigator['allIds'][$navpage+1] != 'unknown') {
+          $nextUrl   = makeAlbumUrl($gallery->session->albumName, $navigator['allIds'][$navpage+1],
+                            array('noCount' => 1));
+
+          echo "\n  ". '<link rel="next" href="'. $nextUrl .'">';
+      }
+      if ($navigator['allIds'][$navcount-1] != 'unknown') {
+          echo "\n  ". '<link rel="last" href="'. $lastUrl .'">';
+      }
+  }
+
+  echo "\n  ". '<link rel="up" href="' . $upUrl .'">';
+
   if ($gallery->album->isRoot() &&
   (!$gallery->session->offline || isset($gallery->session->offlineAlbums["albums.php"]))) {
       echo "\n  ". '<link rel="top" href="'. makeGalleryUrl('albums.php', array('set_albumListPage' => 1)) .'">';
@@ -287,6 +308,10 @@ if (!empty($gallery->album->fields["textcolor"])) {
 
 includeHtmlWrap("photo.header");
 
+if (!empty($allImageAreas)) {
+	echo '<script language="JavaScript" type="text/javascript" src="'. $gallery->app->photoAlbumURL .'/js/wz_tooltip.js"></script>';
+}
+
 $useIcons = (!$iconsForItemOptions || $gallery->app->useIcons == 'no') ? false : true;
 $albumItemOptions = getItemActions($index, $useIcons);
 
@@ -581,7 +606,6 @@ if ($bordercolor) {
 <!-- End Top Nav Bar -->
 </div>
 
-
 <div style="width:<?php echo $mainWidth ?>">
 <?php includeHtmlWrap("inline_photo.header"); ?>
 </div>
@@ -616,8 +640,8 @@ if ($fitToWindow && (eregi('safari|opera', $_SERVER['HTTP_USER_AGENT']) || $gall
     $frame = 'none';
 }
 
-if(empty($full) && $allImageAreas = $gallery->album->getAllImageAreas($index)) {
-    echo showImageMap($index);
+if(empty($full) && !empty($allImageAreas)) {
+    echo showImageMap($index, $href);
     $photoTag = $gallery->album->getPhotoTag($index, $full,"id=\"galleryImage\" usemap=\"#myMap\"");
 }
 else {
@@ -794,9 +818,7 @@ if (isset($printPhotoAccessForm)) { ?>
 <?php }
 
     includeHtmlWrap("photo.footer");
-    if (!empty($allImageAreas)) {
-        echo '<script language="JavaScript" type="text/javascript" src="'. $gallery->app->photoAlbumURL .'/js/wz_tooltip.js"></script>';
-    }
+
     if ($fitToWindow) {
 ?>
 <script type="text/javascript">
